# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateCompound(BaseModel):
    update_compound: Optional["UpdateCompoundUpdateCompound"] = Field(
        alias="updateCompound"
    )


class UpdateCompoundUpdateCompound(BaseModel):
    id: str
    name: str
    description: Optional[str]
    aliases: list[str]


UpdateCompound.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class AllUsers(BaseModel):
    all_users: list["AllUsersAllUsers"] = Field(alias="allUsers")


class AllUsersAllUsers(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


AllUsers.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DietStyle, ExperienceLevel, GoalType, PreferredFormat, TimeBudget


class Me(BaseModel):
    me: Optional["MeMe"]


class MeMe(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str
    profile: Optional["MeMeProfile"]


class MeMeProfile(BaseModel):
    id: str
    user_id: str = Field(alias="userId")
    goals: list["MeMeProfileGoals"]
    experience_level: Optional[ExperienceLevel] = Field(alias="experienceLevel")
    diet_style: Optional[DietStyle] = Field(alias="dietStyle")
    avoidances: list[str]
    time_budget: Optional[TimeBudget] = Field(alias="timeBudget")
    preferred_formats: list[PreferredFormat] = Field(alias="preferredFormats")
    topic_interests: list[str] = Field(alias="topicInterests")
    entity_preferences: Optional["MeMeProfileEntityPreferences"] = Field(
        alias="entityPreferences"
    )
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")


class MeMeProfileGoals(BaseModel):
    goal_type: GoalType = Field(alias="goalType")
    priority: int
    notes: Optional[str]


class MeMeProfileEntityPreferences(BaseModel):
    liked_entity_ids: list[str] = Field(alias="likedEntityIds")
    hidden_entity_ids: list[str] = Field(alias="hiddenEntityIds")
    blocked_entity_ids: list[str] = Field(alias="blockedEntityIds")


Me.model_rebuild()
MeMe.model_rebuild()
MeMeProfile.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateCaseStudy(BaseModel):
    create_case_study: "CreateCaseStudyCreateCaseStudy" = Field(alias="createCaseStudy")


class CreateCaseStudyCreateCaseStudy(BaseModel):
    id: str
    title: str
    summary: str
    url: Optional[str]
    source_type: str = Field(alias="sourceType")


CreateCaseStudy.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DeleteUser(BaseModel):
    delete_user: "DeleteUserDeleteUser" = Field(alias="deleteUser")


class DeleteUserDeleteUser(BaseModel):
    message: str
    success: Optional[bool]


DeleteUser.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class Person(BaseModel):
    person: Optional["PersonPerson"]


class PersonPerson(BaseModel):
    id: str
    name: str
    role: Optional[str]
    bio: Optional[str]
    media_links: Optional[list["PersonPersonMediaLinks"]] = Field(alias="mediaLinks")
    businesses: Optional[list["PersonPersonBusinesses"]]
    episodes: Optional[list["PersonPersonEpisodes"]]


class PersonPersonMediaLinks(BaseModel):
    url: str
    description: Optional[str]


class PersonPersonBusinesses(BaseModel):
    id: str
    name: str
    description: Optional[str]


class PersonPersonEpisodes(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


Person.model_rebuild()
PersonPerson.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EmbedBusinessDescription(BaseModel):
    embed_business_description: "EmbedBusinessDescriptionEmbedBusinessDescription" = (
        Field(alias="embedBusinessDescription")
    )


class EmbedBusinessDescriptionEmbedBusinessDescription(BaseModel):
    id: str
    name: str
    description: Optional[str]


EmbedBusinessDescription.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ProtocolCategory


class CreateProtocol(BaseModel):
    create_protocol: "CreateProtocolCreateProtocol" = Field(alias="createProtocol")


class CreateProtocolCreateProtocol(BaseModel):
    id: str
    name: str
    description: Optional[str]
    categories: list[ProtocolCategory]
    goals: list[str]


CreateProtocol.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateBusinessWithRelations(BaseModel):
    create_business_with_relations: (
        "CreateBusinessWithRelationsCreateBusinessWithRelations"
    ) = Field(alias="createBusinessWithRelations")


class CreateBusinessWithRelationsCreateBusinessWithRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


CreateBusinessWithRelations.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class Business(BaseModel):
    business: Optional["BusinessBusiness"]


class BusinessBusiness(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]
    media_links: Optional[list["BusinessBusinessMediaLinks"]] = Field(
        alias="mediaLinks"
    )
    products: Optional[list["BusinessBusinessProducts"]]
    owners: Optional[list["BusinessBusinessOwners"]]
    executives: Optional[list["BusinessBusinessExecutives"]]
    sponsored_episodes: Optional[list["BusinessBusinessSponsoredEpisodes"]] = Field(
        alias="sponsoredEpisodes"
    )


class BusinessBusinessMediaLinks(BaseModel):
    url: str
    description: Optional[str]


class BusinessBusinessProducts(BaseModel):
    id: str
    name: str
    description: Optional[str]


class BusinessBusinessOwners(BaseModel):
    id: str
    name: str
    role: Optional[str]


class BusinessBusinessExecutives(BaseModel):
    role: Optional[str]
    title: Optional[str]
    person: "BusinessBusinessExecutivesPerson"


class BusinessBusinessExecutivesPerson(BaseModel):
    id: str
    name: str
    role: Optional[str]


class BusinessBusinessSponsoredEpisodes(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


Business.model_rebuild()
BusinessBusiness.model_rebuild()
BusinessBusinessExecutives.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateProtocolRelations(BaseModel):
    update_protocol_relations: Optional[
        "UpdateProtocolRelationsUpdateProtocolRelations"
    ] = Field(alias="updateProtocolRelations")


class UpdateProtocolRelationsUpdateProtocolRelations(BaseModel):
    id: str
    name: str
    products: list["UpdateProtocolRelationsUpdateProtocolRelationsProducts"]
    compounds: list["UpdateProtocolRelationsUpdateProtocolRelationsCompounds"]


class UpdateProtocolRelationsUpdateProtocolRelationsProducts(BaseModel):
    id: str
    name: str


class UpdateProtocolRelationsUpdateProtocolRelationsCompounds(BaseModel):
    id: str
    name: str


UpdateProtocolRelations.model_rebuild()
UpdateProtocolRelationsUpdateProtocolRelations.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteCompound(BaseModel):
    delete_compound: "DeleteCompoundDeleteCompound" = Field(alias="deleteCompound")


class DeleteCompoundDeleteCompound(BaseModel):
    id: str
    name: str


DeleteCompound.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class Product(BaseModel):
    product: Optional["ProductProduct"]


class ProductProduct(BaseModel):
    id: str
    name: str
    description: Optional[str]
    ingredients: list[str]
    source_url: Optional[str] = Field(alias="sourceUrl")
    media_links: Optional[list["ProductProductMediaLinks"]] = Field(alias="mediaLinks")
    business: "ProductProductBusiness"
    compounds: Optional[list["ProductProductCompounds"]]
    sponsor_episodes: Optional[list["ProductProductSponsorEpisodes"]] = Field(
        alias="sponsorEpisodes"
    )


class ProductProductMediaLinks(BaseModel):
    url: str
    description: Optional[str]


class ProductProductBusiness(BaseModel):
    id: str
    name: str
    description: Optional[str]


class ProductProductCompounds(BaseModel):
    id: str
    name: str
    description: Optional[str]


class ProductProductSponsorEpisodes(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


Product.model_rebuild()
ProductProduct.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Login(BaseModel):
    login: "LoginLogin"


class LoginLogin(BaseModel):
    token: str
    user: "LoginLoginUser"


class LoginLoginUser(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


Login.model_rebuild()
LoginLogin.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/schema.graphql

from enum import Enum


class UserProtocolStatus(str, Enum):
    draft = "draft"
    active = "active"
    archived = "archived"


class UserGoalType(str, Enum):
    sleep = "sleep"
    energy = "energy"
    fatLoss = "fatLoss"
    cognition = "cognition"
    longevity = "longevity"
    strength = "strength"
    stress = "stress"
    recovery = "recovery"
    other = "other"


class ProtocolStepItemType(str, Enum):
    PRODUCT = "PRODUCT"
    COMPOUND = "COMPOUND"
    ACTION = "ACTION"


class ProtocolTimeOfDay(str, Enum):
    morning = "morning"
    midday = "midday"
    evening = "evening"
    bedtime = "bedtime"
    any = "any"


class EvidenceRefType(str, Enum):
    episode = "episode"
    caseStudy = "caseStudy"
    article = "article"
    external = "external"


class ArticleSourceType(str, Enum):
    human_upgrade = "human_upgrade"
    external = "external"


class GoalType(str, Enum):
    sleep = "sleep"
    energy = "energy"
    fatLoss = "fatLoss"
    cognition = "cognition"
    longevity = "longevity"
    strength = "strength"
    stress = "stress"
    recovery = "recovery"
    other = "other"


class ExperienceLevel(str, Enum):
    beginner = "beginner"
    intermediate = "intermediate"
    advanced = "advanced"


class DietStyle(str, Enum):
    none = "none"
    keto = "keto"
    paleo = "paleo"
    vegan = "vegan"
    vegetarian = "vegetarian"
    mediterranean = "mediterranean"
    lowCarb = "lowCarb"
    omnivore = "omnivore"
    other = "other"


class TimeBudget(str, Enum):
    min5 = "min5"
    min15 = "min15"
    min30 = "min30"
    min60 = "min60"


class PreferredFormat(str, Enum):
    video = "video"
    summary = "summary"
    protocol = "protocol"
    caseStudy = "caseStudy"


class UserProvider(str, Enum):
    LOCAL = "LOCAL"
    GOOGLE = "GOOGLE"
    GITHUB = "GITHUB"
    APPLE = "APPLE"


class UserRole(str, Enum):
    ADMIN = "ADMIN"
    USER = "USER"


class ProtocolCategory(str, Enum):
    sleep = "sleep"
    circadian = "circadian"
    fitness = "fitness"
    nutrition = "nutrition"
    cognition = "cognition"
    stress = "stress"
    recovery = "recovery"
    longevity = "longevity"
    health = "health"
    other = "other"


class CaseStudySourceType(str, Enum):
    PUBMED = "PUBMED"
    CLINICAL_TRIAL = "CLINICAL_TRIAL"
    ARTICLE = "ARTICLE"
    OTHER = "OTHER"


class SavedEntityType(str, Enum):
    product = "product"
    compound = "compound"
    person = "person"
    business = "business"
    protocol = "protocol"
    episode = "episode"
    caseStudy = "caseStudy"
    article = "article"


class SaveSource(str, Enum):
    dashboard = "dashboard"
    episode = "episode"
    assistant = "assistant"
    search = "search"
    protocol_builder = "protocol_builder"
    profile = "profile"
    other = "other"



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateCompoundRelations(BaseModel):
    update_compound_relations: Optional[
        "UpdateCompoundRelationsUpdateCompoundRelations"
    ] = Field(alias="updateCompoundRelations")


class UpdateCompoundRelationsUpdateCompoundRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]


UpdateCompoundRelations.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class EmbedPersonBio(BaseModel):
    embed_person_bio: "EmbedPersonBioEmbedPersonBio" = Field(alias="embedPersonBio")


class EmbedPersonBioEmbedPersonBio(BaseModel):
    id: str
    name: str
    bio: Optional[str]


EmbedPersonBio.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Compounds(BaseModel):
    compounds: list["CompoundsCompounds"]


class CompoundsCompounds(BaseModel):
    id: str
    name: str
    description: Optional[str]
    aliases: list[str]


Compounds.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateEpisodeRelations(BaseModel):
    update_episode_relations: Optional[
        "UpdateEpisodeRelationsUpdateEpisodeRelations"
    ] = Field(alias="updateEpisodeRelations")


class UpdateEpisodeRelationsUpdateEpisodeRelations(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


UpdateEpisodeRelations.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import DietStyle, ExperienceLevel, GoalType, PreferredFormat, TimeBudget


class UpsertUserProfile(BaseModel):
    upsert_user_profile: "UpsertUserProfileUpsertUserProfile" = Field(
        alias="upsertUserProfile"
    )


class UpsertUserProfileUpsertUserProfile(BaseModel):
    id: str
    user_id: str = Field(alias="userId")
    goals: list["UpsertUserProfileUpsertUserProfileGoals"]
    experience_level: Optional[ExperienceLevel] = Field(alias="experienceLevel")
    diet_style: Optional[DietStyle] = Field(alias="dietStyle")
    avoidances: list[str]
    time_budget: Optional[TimeBudget] = Field(alias="timeBudget")
    preferred_formats: list[PreferredFormat] = Field(alias="preferredFormats")
    topic_interests: list[str] = Field(alias="topicInterests")
    entity_preferences: Optional[
        "UpsertUserProfileUpsertUserProfileEntityPreferences"
    ] = Field(alias="entityPreferences")
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")


class UpsertUserProfileUpsertUserProfileGoals(BaseModel):
    goal_type: GoalType = Field(alias="goalType")
    priority: int
    notes: Optional[str]


class UpsertUserProfileUpsertUserProfileEntityPreferences(BaseModel):
    liked_entity_ids: list[str] = Field(alias="likedEntityIds")
    hidden_entity_ids: list[str] = Field(alias="hiddenEntityIds")
    blocked_entity_ids: list[str] = Field(alias="blockedEntityIds")


UpsertUserProfile.model_rebuild()
UpsertUserProfileUpsertUserProfile.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateBusinessRelations(BaseModel):
    update_business_relations: Optional[
        "UpdateBusinessRelationsUpdateBusinessRelations"
    ] = Field(alias="updateBusinessRelations")


class UpdateBusinessRelationsUpdateBusinessRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


UpdateBusinessRelations.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Products(BaseModel):
    products: list["ProductsProducts"]


class ProductsProducts(BaseModel):
    id: str
    name: str
    description: Optional[str]
    ingredients: list[str]


Products.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreatePerson(BaseModel):
    create_person: "CreatePersonCreatePerson" = Field(alias="createPerson")


class CreatePersonCreatePerson(BaseModel):
    id: str
    name: str
    role: Optional[str]
    bio: Optional[str]


CreatePerson.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class VectorSearchPeople(BaseModel):
    vector_search_people: Optional[list["VectorSearchPeopleVectorSearchPeople"]] = (
        Field(alias="vectorSearchPeople")
    )


class VectorSearchPeopleVectorSearchPeople(BaseModel):
    id: str
    name: str
    bio: str
    score: Optional[float]


VectorSearchPeople.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CaseStudy(BaseModel):
    case_study: Optional["CaseStudyCaseStudy"] = Field(alias="caseStudy")


class CaseStudyCaseStudy(BaseModel):
    id: str
    title: str
    summary: str
    url: Optional[str]
    source_type: str = Field(alias="sourceType")
    media_links: Optional[list["CaseStudyCaseStudyMediaLinks"]] = Field(
        alias="mediaLinks"
    )
    episodes: Optional[list["CaseStudyCaseStudyEpisodes"]]
    compounds: Optional[list["CaseStudyCaseStudyCompounds"]]
    products: Optional[list["CaseStudyCaseStudyProducts"]]
    protocols: Optional[list["CaseStudyCaseStudyProtocols"]]


class CaseStudyCaseStudyMediaLinks(BaseModel):
    url: str
    description: Optional[str]


class CaseStudyCaseStudyEpisodes(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


class CaseStudyCaseStudyCompounds(BaseModel):
    id: str
    name: str
    description: Optional[str]


class CaseStudyCaseStudyProducts(BaseModel):
    id: str
    name: str
    description: Optional[str]


class CaseStudyCaseStudyProtocols(BaseModel):
    id: str
    name: str
    description: Optional[str]


CaseStudy.model_rebuild()
CaseStudyCaseStudy.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SavedEntityType, SaveSource


class SaveEntity(BaseModel):
    save_entity: "SaveEntitySaveEntity" = Field(alias="saveEntity")


class SaveEntitySaveEntity(BaseModel):
    id: str
    user_id: str = Field(alias="userId")
    target_type: SavedEntityType = Field(alias="targetType")
    target_id: str = Field(alias="targetId")
    note: Optional[str]
    tags: list[str]
    pinned: bool
    source: Optional[SaveSource]
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")


SaveEntity.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteAllEpisodes(BaseModel):
    delete_all_episodes: "DeleteAllEpisodesDeleteAllEpisodes" = Field(
        alias="deleteAllEpisodes"
    )


class DeleteAllEpisodesDeleteAllEpisodes(BaseModel):
    deleted_count: int = Field(alias="deletedCount")


DeleteAllEpisodes.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Annotated, Any, Literal, Optional, Union

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    EvidenceRefType,
    ProtocolStepItemType,
    ProtocolTimeOfDay,
    UserGoalType,
    UserProtocolStatus,
)


class MyUserProtocols(BaseModel):
    my_user_protocols: "MyUserProtocolsMyUserProtocols" = Field(alias="myUserProtocols")


class MyUserProtocolsMyUserProtocols(BaseModel):
    edges: list["MyUserProtocolsMyUserProtocolsEdges"]
    page_info: "MyUserProtocolsMyUserProtocolsPageInfo" = Field(alias="pageInfo")


class MyUserProtocolsMyUserProtocolsEdges(BaseModel):
    cursor: str
    node: "MyUserProtocolsMyUserProtocolsEdgesNode"


class MyUserProtocolsMyUserProtocolsEdgesNode(BaseModel):
    id: str
    user_id: str = Field(alias="userId")
    title: str
    goal_type: Optional[UserGoalType] = Field(alias="goalType")
    status: UserProtocolStatus
    source_protocol_id: Optional[str] = Field(alias="sourceProtocolId")
    steps_structured: list["MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructured"] = (
        Field(alias="stepsStructured")
    )
    evidence_refs: list["MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefs"] = Field(
        alias="evidenceRefs"
    )
    safety: Optional["MyUserProtocolsMyUserProtocolsEdgesNodeSafety"]
    last_edited_at: Optional[Any] = Field(alias="lastEditedAt")
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")


class MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructured(BaseModel):
    label: Optional[str]
    time_of_day: Optional[ProtocolTimeOfDay] = Field(alias="timeOfDay")
    items: list["MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItems"]


class MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItems(BaseModel):
    type: ProtocolStepItemType
    ref_id: Optional[str] = Field(alias="refId")
    name_override: Optional[str] = Field(alias="nameOverride")
    dosage: Optional[str]
    timing: Optional[str]
    notes: Optional[str]
    item_entity: Optional[
        Annotated[
            Union[
                "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityProduct",
                "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityCompound",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="itemEntity")


class MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityProduct(
    BaseModel
):
    typename__: Literal["Product"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityCompound(
    BaseModel
):
    typename__: Literal["Compound"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefs(BaseModel):
    type: EvidenceRefType
    ref_id: Optional[str] = Field(alias="refId")
    label: Optional[str]
    url: Optional[str]
    episode_id: Optional[str] = Field(alias="episodeId")
    timestamps: list[int]
    notes: Optional[str]
    evidence_ref_entity: Optional[
        Annotated[
            Union[
                "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityArticle",
                "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityCaseStudy",
                "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityEpisode",
                "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityExternal",
            ],
            Field(discriminator="typename__"),
        ]
    ] = Field(alias="evidenceRefEntity")


class MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityArticle(
    BaseModel
):
    typename__: Literal["Article"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityCaseStudy(
    BaseModel
):
    typename__: Literal["CaseStudy"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityEpisode(
    BaseModel
):
    typename__: Literal["Episode"] = Field(alias="__typename")
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


class MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityExternal(
    BaseModel
):
    typename__: Literal["External"] = Field(alias="__typename")
    url: Optional[str]
    label: Optional[str]


class MyUserProtocolsMyUserProtocolsEdgesNodeSafety(BaseModel):
    warnings: list[str]
    contraindications: list[str]
    interactions: list[str]
    notes: Optional[str]


class MyUserProtocolsMyUserProtocolsPageInfo(BaseModel):
    has_next_page: bool = Field(alias="hasNextPage")
    end_cursor: Optional[str] = Field(alias="endCursor")


MyUserProtocols.model_rebuild()
MyUserProtocolsMyUserProtocols.model_rebuild()
MyUserProtocolsMyUserProtocolsEdges.model_rebuild()
MyUserProtocolsMyUserProtocolsEdgesNode.model_rebuild()
MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructured.model_rebuild()
MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItems.model_rebuild()
MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefs.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateProductRelations(BaseModel):
    update_product_relations: Optional[
        "UpdateProductRelationsUpdateProductRelations"
    ] = Field(alias="updateProductRelations")


class UpdateProductRelationsUpdateProductRelations(BaseModel):
    id: str
    name: str
    description: Optional[str]


UpdateProductRelations.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class Episode(BaseModel):
    episode: Optional["EpisodeEpisode"]


class EpisodeEpisode(BaseModel):
    id: str
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber")
    episode_title: Optional[str] = Field(alias="episodeTitle")
    episode_transcript_url: Optional[str] = Field(alias="episodeTranscriptUrl")
    episode_page_url: Optional[str] = Field(alias="episodePageUrl")
    web_page_summary: Optional[str] = Field(alias="webPageSummary")
    web_page_timelines: Optional[list["EpisodeEpisodeWebPageTimelines"]] = Field(
        alias="webPageTimelines"
    )
    sponsor_link_objects: Optional[list["EpisodeEpisodeSponsorLinkObjects"]] = Field(
        alias="sponsorLinkObjects"
    )
    takeaways: list[str]
    s_3_transcript_key: Optional[str] = Field(alias="s3TranscriptKey")
    s_3_transcript_url: Optional[str] = Field(alias="s3TranscriptUrl")
    youtube_video_id: Optional[str] = Field(alias="youtubeVideoId")
    youtube_watch_url: Optional[str] = Field(alias="youtubeWatchUrl")
    youtube_embed_url: Optional[str] = Field(alias="youtubeEmbedUrl")
    media_links: Optional[list["EpisodeEpisodeMediaLinks"]] = Field(alias="mediaLinks")
    published_at: Optional[Any] = Field(alias="publishedAt")
    guests: Optional[list["EpisodeEpisodeGuests"]]
    summary_short: Optional[str] = Field(alias="summaryShort")
    summary_detailed: Optional[str] = Field(alias="summaryDetailed")
    published_summary: Optional[str] = Field(alias="publishedSummary")
    business_links: Optional[list[str]] = Field(alias="businessLinks")
    sponsor_businesses: Optional[list["EpisodeEpisodeSponsorBusinesses"]] = Field(
        alias="sponsorBusinesses"
    )
    protocols: Optional[list["EpisodeEpisodeProtocols"]]


class EpisodeEpisodeWebPageTimelines(BaseModel):
    from_: str = Field(alias="from")
    to: str
    title: Optional[str]
    description: Optional[str]


class EpisodeEpisodeSponsorLinkObjects(BaseModel):
    text: Optional[str]
    links: Optional[list[str]]
    has_code_dave: Optional[bool] = Field(alias="hasCodeDave")
    code: Optional[str]
    brand: Optional[str]
    discount_percent: Optional[float] = Field(alias="discountPercent")


class EpisodeEpisodeMediaLinks(BaseModel):
    url: str
    description: Optional[str]


class EpisodeEpisodeGuests(BaseModel):
    id: str
    name: str
    role: Optional[str]


class EpisodeEpisodeSponsorBusinesses(BaseModel):
    id: str
    name: str
    description: Optional[str]


class EpisodeEpisodeProtocols(BaseModel):
    id: str
    name: str
    description: Optional[str]


Episode.model_rebuild()
EpisodeEpisode.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Annotated, Any, Literal, Optional, Union

from pydantic import Field

from .base_model import BaseModel
from .enums import SavedEntityType, SaveSource


class SavedEntities(BaseModel):
    saved_entities: "SavedEntitiesSavedEntities" = Field(alias="savedEntities")


class SavedEntitiesSavedEntities(BaseModel):
    edges: list["SavedEntitiesSavedEntitiesEdges"]
    page_info: "SavedEntitiesSavedEntitiesPageInfo" = Field(alias="pageInfo")


class SavedEntitiesSavedEntitiesEdges(BaseModel):
    cursor: str
    node: "SavedEntitiesSavedEntitiesEdgesNode"


class SavedEntitiesSavedEntitiesEdgesNode(BaseModel):
    id: str
    user_id: str = Field(alias="userId")
    target_type: SavedEntityType = Field(alias="targetType")
    target_id: str = Field(alias="targetId")
    note: Optional[str]
    tags: list[str]
    pinned: bool
    source: Optional[SaveSource]
    created_at: Any = Field(alias="createdAt")
    updated_at: Any = Field(alias="updatedAt")
    target: Optional[
        Annotated[
            Union[
                "SavedEntitiesSavedEntitiesEdgesNodeTargetProduct",
                "SavedEntitiesSavedEntitiesEdgesNodeTargetCompound",
                "SavedEntitiesSavedEntitiesEdgesNodeTargetCaseStudy",
                "SavedEntitiesSavedEntitiesEdgesNodeTargetProtocol",
                "SavedEntitiesSavedEntitiesEdgesNodeTargetPerson",
                "SavedEntitiesSavedEntitiesEdgesNodeTargetBusiness",
                "SavedEntitiesSavedEntitiesEdgesNodeTargetEpisode",
                "SavedEntitiesSavedEntitiesEdgesNodeTargetArticle",
            ],
            Field(discriminator="typename__"),
        ]
    ]


class SavedEntitiesSavedEntitiesEdgesNodeTargetProduct(BaseModel):
    typename__: Literal["Product"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class SavedEntitiesSavedEntitiesEdgesNodeTargetCompound(BaseModel):
    typename__: Literal["Compound"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class SavedEntitiesSavedEntitiesEdgesNodeTargetCaseStudy(BaseModel):
    typename__: Literal["CaseStudy"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class SavedEntitiesSavedEntitiesEdgesNodeTargetProtocol(BaseModel):
    typename__: Literal["Protocol"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class SavedEntitiesSavedEntitiesEdgesNodeTargetPerson(BaseModel):
    typename__: Literal["Person"] = Field(alias="__typename")
    id: str
    name: str
    role: Optional[str]


class SavedEntitiesSavedEntitiesEdgesNodeTargetBusiness(BaseModel):
    typename__: Literal["Business"] = Field(alias="__typename")
    id: str
    name: str
    description: Optional[str]


class SavedEntitiesSavedEntitiesEdgesNodeTargetEpisode(BaseModel):
    typename__: Literal["Episode"] = Field(alias="__typename")
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")


class SavedEntitiesSavedEntitiesEdgesNodeTargetArticle(BaseModel):
    typename__: Literal["Article"] = Field(alias="__typename")
    id: str
    title: str
    summary: str


class SavedEntitiesSavedEntitiesPageInfo(BaseModel):
    has_next_page: bool = Field(alias="hasNextPage")
    end_cursor: Optional[str] = Field(alias="endCursor")


SavedEntities.model_rebuild()
SavedEntitiesSavedEntities.model_rebuild()
SavedEntitiesSavedEntitiesEdges.model_rebuild()
SavedEntitiesSavedEntitiesEdgesNode.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteBusiness(BaseModel):
    delete_business: "DeleteBusinessDeleteBusiness" = Field(alias="deleteBusiness")


class DeleteBusinessDeleteBusiness(BaseModel):
    deleted_count: int = Field(alias="deletedCount")


DeleteBusiness.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Businesses(BaseModel):
    businesses: list["BusinessesBusinesses"]


class BusinessesBusinesses(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


Businesses.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional, Union

from .all_users import AllUsers
from .async_base_client import AsyncBaseClient
from .base_model import UNSET, UnsetType
from .business import Business
from .businesses import Businesses
from .case_studies import CaseStudies
from .case_study import CaseStudy
from .compound import Compound
from .compounds import Compounds
from .create_business_with_relations import CreateBusinessWithRelations
from .create_case_study import CreateCaseStudy
from .create_compound import CreateCompound
from .create_episode import CreateEpisode
from .create_person import CreatePerson
from .create_product import CreateProduct
from .create_protocol import CreateProtocol
from .create_user_protocol import CreateUserProtocol
from .delete_all_episodes import DeleteAllEpisodes
from .delete_business import DeleteBusiness
from .delete_compound import DeleteCompound
from .delete_episode import DeleteEpisode
from .delete_person import DeletePerson
from .delete_product import DeleteProduct
from .delete_protocol import DeleteProtocol
from .delete_user import DeleteUser
from .delete_user_profile import DeleteUserProfile
from .delete_user_protocol import DeleteUserProtocol
from .embed_business_description import EmbedBusinessDescription
from .embed_person_bio import EmbedPersonBio
from .embed_product_description import EmbedProductDescription
from .episode import Episode
from .episodes import Episodes
from .input_types import (
    BusinessCreateRelationsInput,
    BusinessUpdateRelationFieldsInput,
    BusinessUpdateWithIdsInput,
    CaseStudyCreateWithOptionalIdsInput,
    CaseStudyUpdateWithOptionalIdsInput,
    CompoundCreateWithIdsInput,
    CompoundUpdateRelationFieldsInput,
    CompoundUpdateWithIdsInput,
    CreateUserProtocolInput,
    CursorPageInput,
    EpisodeCreateWithIdsInput,
    EpisodeUpdateRelationFieldsInput,
    EpisodeUpdateWithIdsInput,
    PersonCreateInput,
    PersonUpdateInput,
    ProductCreateWithIdsInput,
    ProductUpdateRelationFieldsInput,
    ProductUpdateWithIdsInput,
    ProtocolCreateWithIdsInput,
    ProtocolUpdateRelationFieldsInput,
    ProtocolUpdateWithIdsInput,
    SavedEntitiesFilterInput,
    SaveEntityInput,
    UnsaveEntityInput,
    UpdateUserProtocolInput,
    UserProfileUpsertInput,
    UserProtocolsFilterInput,
    UserUpsertInput,
    VectorSearchArgs,
)
from .login import Login
from .me import Me
from .my_profile import MyProfile
from .my_user_protocols import MyUserProtocols
from .people import People
from .person import Person
from .product import Product
from .products import Products
from .protocol import Protocol
from .protocols import Protocols
from .register import Register
from .save_entity import SaveEntity
from .saved_entities import SavedEntities
from .unsave_entity import UnsaveEntity
from .update_business import UpdateBusiness
from .update_business_relations import UpdateBusinessRelations
from .update_case_study import UpdateCaseStudy
from .update_compound import UpdateCompound
from .update_compound_relations import UpdateCompoundRelations
from .update_episode import UpdateEpisode
from .update_episode_relations import UpdateEpisodeRelations
from .update_person import UpdatePerson
from .update_product import UpdateProduct
from .update_product_relations import UpdateProductRelations
from .update_protocol import UpdateProtocol
from .update_protocol_relations import UpdateProtocolRelations
from .update_user_protocol import UpdateUserProtocol
from .upsert_user import UpsertUser
from .upsert_user_profile import UpsertUserProfile
from .vector_search_businesses import VectorSearchBusinesses
from .vector_search_people import VectorSearchPeople
from .vector_search_products import VectorSearchProducts


def gql(q: str) -> str:
    return q


class Client(AsyncBaseClient):
    async def register(
        self,
        email: str,
        password: str,
        name: Union[Optional[str], UnsetType] = UNSET,
        **kwargs: Any
    ) -> Register:
        query = gql(
            """
            mutation Register($email: String!, $password: String!, $name: String) {
              register(email: $email, password: $password, name: $name) {
                token
                user {
                  id
                  email
                  name
                  role
                }
              }
            }
            """
        )
        variables: dict[str, object] = {
            "email": email,
            "password": password,
            "name": name,
        }
        response = await self.execute(
            query=query, operation_name="Register", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Register.model_validate(data)

    async def login(self, email: str, password: str, **kwargs: Any) -> Login:
        query = gql(
            """
            mutation Login($email: String!, $password: String!) {
              login(email: $email, password: $password) {
                token
                user {
                  id
                  email
                  name
                  role
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"email": email, "password": password}
        response = await self.execute(
            query=query, operation_name="Login", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Login.model_validate(data)

    async def upsert_user_profile(
        self, input: UserProfileUpsertInput, **kwargs: Any
    ) -> UpsertUserProfile:
        query = gql(
            """
            mutation UpsertUserProfile($input: UserProfileUpsertInput!) {
              upsertUserProfile(input: $input) {
                id
                userId
                goals {
                  goalType
                  priority
                  notes
                }
                experienceLevel
                dietStyle
                avoidances
                timeBudget
                preferredFormats
                topicInterests
                entityPreferences {
                  likedEntityIds
                  hiddenEntityIds
                  blockedEntityIds
                }
                createdAt
                updatedAt
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="UpsertUserProfile",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpsertUserProfile.model_validate(data)

    async def delete_user_profile(
        self, user_id: str, **kwargs: Any
    ) -> DeleteUserProfile:
        query = gql(
            """
            mutation DeleteUserProfile($userId: ID!) {
              deleteUserProfile(userId: $userId) {
                deletedCount
              }
            }
            """
        )
        variables: dict[str, object] = {"userId": user_id}
        response = await self.execute(
            query=query,
            operation_name="DeleteUserProfile",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return DeleteUserProfile.model_validate(data)

    async def delete_user(self, user_id: str, **kwargs: Any) -> DeleteUser:
        query = gql(
            """
            mutation DeleteUser($userId: ID!) {
              deleteUser(userId: $userId) {
                message
                success
              }
            }
            """
        )
        variables: dict[str, object] = {"userId": user_id}
        response = await self.execute(
            query=query, operation_name="DeleteUser", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return DeleteUser.model_validate(data)

    async def upsert_user(self, input: UserUpsertInput, **kwargs: Any) -> UpsertUser:
        query = gql(
            """
            mutation UpsertUser($input: UserUpsertInput!) {
              upsertUser(input: $input) {
                id
                email
                name
                role
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpsertUser", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpsertUser.model_validate(data)

    async def create_business_with_relations(
        self, input: BusinessCreateRelationsInput, **kwargs: Any
    ) -> CreateBusinessWithRelations:
        query = gql(
            """
            mutation CreateBusinessWithRelations($input: BusinessCreateRelationsInput!) {
              createBusinessWithRelations(input: $input) {
                id
                name
                description
                website
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="CreateBusinessWithRelations",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CreateBusinessWithRelations.model_validate(data)

    async def update_business(
        self, input: BusinessUpdateWithIdsInput, **kwargs: Any
    ) -> UpdateBusiness:
        query = gql(
            """
            mutation UpdateBusiness($input: BusinessUpdateWithIdsInput!) {
              updateBusiness(input: $input) {
                id
                name
                description
                website
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpdateBusiness", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateBusiness.model_validate(data)

    async def update_business_relations(
        self, input: BusinessUpdateRelationFieldsInput, **kwargs: Any
    ) -> UpdateBusinessRelations:
        query = gql(
            """
            mutation UpdateBusinessRelations($input: BusinessUpdateRelationFieldsInput!) {
              updateBusinessRelations(input: $input) {
                id
                name
                description
                website
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="UpdateBusinessRelations",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateBusinessRelations.model_validate(data)

    async def delete_business(self, id: str, **kwargs: Any) -> DeleteBusiness:
        query = gql(
            """
            mutation DeleteBusiness($id: ID!) {
              deleteBusiness(id: $id) {
                deletedCount
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="DeleteBusiness", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return DeleteBusiness.model_validate(data)

    async def create_product(
        self, input: ProductCreateWithIdsInput, **kwargs: Any
    ) -> CreateProduct:
        query = gql(
            """
            mutation CreateProduct($input: ProductCreateWithIdsInput!) {
              createProduct(input: $input) {
                id
                name
                description
                ingredients
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="CreateProduct", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CreateProduct.model_validate(data)

    async def update_product(
        self, input: ProductUpdateWithIdsInput, **kwargs: Any
    ) -> UpdateProduct:
        query = gql(
            """
            mutation UpdateProduct($input: ProductUpdateWithIdsInput!) {
              updateProduct(input: $input) {
                id
                name
                description
                ingredients
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpdateProduct", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateProduct.model_validate(data)

    async def update_product_relations(
        self, input: ProductUpdateRelationFieldsInput, **kwargs: Any
    ) -> UpdateProductRelations:
        query = gql(
            """
            mutation UpdateProductRelations($input: ProductUpdateRelationFieldsInput!) {
              updateProductRelations(input: $input) {
                id
                name
                description
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="UpdateProductRelations",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateProductRelations.model_validate(data)

    async def delete_product(self, id: str, **kwargs: Any) -> DeleteProduct:
        query = gql(
            """
            mutation DeleteProduct($id: ID!) {
              deleteProduct(id: $id) {
                id
                name
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="DeleteProduct", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return DeleteProduct.model_validate(data)

    async def embed_product_description(
        self, product_id: str, **kwargs: Any
    ) -> EmbedProductDescription:
        query = gql(
            """
            mutation EmbedProductDescription($productId: ID!) {
              embedProductDescription(productId: $productId) {
                id
                name
                description
              }
            }
            """
        )
        variables: dict[str, object] = {"productId": product_id}
        response = await self.execute(
            query=query,
            operation_name="EmbedProductDescription",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return EmbedProductDescription.model_validate(data)

    async def create_person(
        self, input: PersonCreateInput, **kwargs: Any
    ) -> CreatePerson:
        query = gql(
            """
            mutation CreatePerson($input: PersonCreateInput!) {
              createPerson(input: $input) {
                id
                name
                role
                bio
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="CreatePerson", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CreatePerson.model_validate(data)

    async def update_person(
        self, input: PersonUpdateInput, **kwargs: Any
    ) -> UpdatePerson:
        query = gql(
            """
            mutation UpdatePerson($input: PersonUpdateInput!) {
              updatePerson(input: $input) {
                id
                name
                role
                bio
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpdatePerson", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdatePerson.model_validate(data)

    async def delete_person(self, id: str, **kwargs: Any) -> DeletePerson:
        query = gql(
            """
            mutation DeletePerson($id: ID!) {
              deletePerson(id: $id) {
                id
                name
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="DeletePerson", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return DeletePerson.model_validate(data)

    async def embed_person_bio(self, person_id: str, **kwargs: Any) -> EmbedPersonBio:
        query = gql(
            """
            mutation EmbedPersonBio($personId: ID!) {
              embedPersonBio(personId: $personId) {
                id
                name
                bio
              }
            }
            """
        )
        variables: dict[str, object] = {"personId": person_id}
        response = await self.execute(
            query=query, operation_name="EmbedPersonBio", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return EmbedPersonBio.model_validate(data)

    async def create_episode(
        self, input: EpisodeCreateWithIdsInput, **kwargs: Any
    ) -> CreateEpisode:
        query = gql(
            """
            mutation CreateEpisode($input: EpisodeCreateWithIdsInput!) {
              createEpisode(input: $input) {
                id
                episodeTitle
                channelName
                episodeNumber
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="CreateEpisode", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CreateEpisode.model_validate(data)

    async def update_episode(
        self, input: EpisodeUpdateWithIdsInput, **kwargs: Any
    ) -> UpdateEpisode:
        query = gql(
            """
            mutation UpdateEpisode($input: EpisodeUpdateWithIdsInput!) {
              updateEpisode(input: $input) {
                id
                episodeTitle
                channelName
                episodeNumber
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpdateEpisode", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateEpisode.model_validate(data)

    async def update_episode_relations(
        self, input: EpisodeUpdateRelationFieldsInput, **kwargs: Any
    ) -> UpdateEpisodeRelations:
        query = gql(
            """
            mutation UpdateEpisodeRelations($input: EpisodeUpdateRelationFieldsInput!) {
              updateEpisodeRelations(input: $input) {
                id
                episodeTitle
                channelName
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="UpdateEpisodeRelations",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateEpisodeRelations.model_validate(data)

    async def delete_episode(self, identifier: str, **kwargs: Any) -> DeleteEpisode:
        query = gql(
            """
            mutation DeleteEpisode($identifier: String!) {
              deleteEpisode(identifier: $identifier) {
                id
                episodeTitle
              }
            }
            """
        )
        variables: dict[str, object] = {"identifier": identifier}
        response = await self.execute(
            query=query, operation_name="DeleteEpisode", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return DeleteEpisode.model_validate(data)

    async def delete_all_episodes(self, **kwargs: Any) -> DeleteAllEpisodes:
        query = gql(
            """
            mutation DeleteAllEpisodes {
              deleteAllEpisodes {
                deletedCount
              }
            }
            """
        )
        variables: dict[str, object] = {}
        response = await self.execute(
            query=query,
            operation_name="DeleteAllEpisodes",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return DeleteAllEpisodes.model_validate(data)

    async def create_compound(
        self, input: CompoundCreateWithIdsInput, **kwargs: Any
    ) -> CreateCompound:
        query = gql(
            """
            mutation CreateCompound($input: CompoundCreateWithIdsInput!) {
              createCompound(input: $input) {
                id
                name
                description
                aliases
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="CreateCompound", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CreateCompound.model_validate(data)

    async def update_compound(
        self, input: CompoundUpdateWithIdsInput, **kwargs: Any
    ) -> UpdateCompound:
        query = gql(
            """
            mutation UpdateCompound($input: CompoundUpdateWithIdsInput!) {
              updateCompound(input: $input) {
                id
                name
                description
                aliases
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpdateCompound", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateCompound.model_validate(data)

    async def update_compound_relations(
        self, input: CompoundUpdateRelationFieldsInput, **kwargs: Any
    ) -> UpdateCompoundRelations:
        query = gql(
            """
            mutation UpdateCompoundRelations($input: CompoundUpdateRelationFieldsInput!) {
              updateCompoundRelations(input: $input) {
                id
                name
                description
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="UpdateCompoundRelations",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateCompoundRelations.model_validate(data)

    async def delete_compound(self, id: str, **kwargs: Any) -> DeleteCompound:
        query = gql(
            """
            mutation DeleteCompound($id: ID!) {
              deleteCompound(id: $id) {
                id
                name
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="DeleteCompound", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return DeleteCompound.model_validate(data)

    async def create_protocol(
        self, input: ProtocolCreateWithIdsInput, **kwargs: Any
    ) -> CreateProtocol:
        query = gql(
            """
            mutation CreateProtocol($input: ProtocolCreateWithIdsInput!) {
              createProtocol(input: $input) {
                id
                name
                description
                categories
                goals
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="CreateProtocol", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CreateProtocol.model_validate(data)

    async def update_protocol(
        self, input: ProtocolUpdateWithIdsInput, **kwargs: Any
    ) -> UpdateProtocol:
        query = gql(
            """
            mutation UpdateProtocol($input: ProtocolUpdateWithIdsInput!) {
              updateProtocol(input: $input) {
                id
                name
                description
                categories
                goals
                steps
                cautions
                aliases
                sourceUrl
                stepsStructured {
                  label
                  timeOfDay
                  items {
                    type
                    refId
                    nameOverride
                    dosage
                    timing
                    notes
                    itemEntity {
                      __typename
                      ... on Product {
                        id
                        name
                        description
                      }
                      ... on Compound {
                        id
                        name
                        description
                      }
                    }
                  }
                }
                evidenceRefs {
                  type
                  refId
                  label
                  url
                  episodeId
                  timestamps
                  notes
                  evidenceRefEntity {
                    __typename
                    ... on Article {
                      id
                      title
                      articleSummary: summary
                    }
                    ... on CaseStudy {
                      id
                      title
                      summary
                    }
                    ... on Episode {
                      id
                      episodeTitle
                      channelName
                    }
                    ... on External {
                      url
                      label
                    }
                  }
                }
                safety {
                  warnings
                  contraindications
                  interactions
                  notes
                }
                products {
                  id
                  name
                }
                compounds {
                  id
                  name
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpdateProtocol", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateProtocol.model_validate(data)

    async def update_protocol_relations(
        self, input: ProtocolUpdateRelationFieldsInput, **kwargs: Any
    ) -> UpdateProtocolRelations:
        query = gql(
            """
            mutation UpdateProtocolRelations($input: ProtocolUpdateRelationFieldsInput!) {
              updateProtocolRelations(input: $input) {
                id
                name
                products {
                  id
                  name
                }
                compounds {
                  id
                  name
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="UpdateProtocolRelations",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateProtocolRelations.model_validate(data)

    async def delete_protocol(self, id: str, **kwargs: Any) -> DeleteProtocol:
        query = gql(
            """
            mutation DeleteProtocol($id: ID!) {
              deleteProtocol(id: $id) {
                id
                name
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="DeleteProtocol", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return DeleteProtocol.model_validate(data)

    async def create_user_protocol(
        self, input: CreateUserProtocolInput, **kwargs: Any
    ) -> CreateUserProtocol:
        query = gql(
            """
            mutation CreateUserProtocol($input: CreateUserProtocolInput!) {
              createUserProtocol(input: $input) {
                id
                userId
                title
                goalType
                status
                sourceProtocolId
                stepsStructured {
                  label
                  timeOfDay
                  items {
                    type
                    refId
                    nameOverride
                    dosage
                    timing
                    notes
                    itemEntity {
                      __typename
                      ... on Product {
                        id
                        name
                        description
                      }
                      ... on Compound {
                        id
                        name
                        description
                      }
                    }
                  }
                }
                evidenceRefs {
                  type
                  refId
                  label
                  url
                  episodeId
                  timestamps
                  notes
                  evidenceRefEntity {
                    __typename
                    ... on Article {
                      id
                      title
                      articleSummary: summary
                    }
                    ... on CaseStudy {
                      id
                      title
                      summary
                    }
                    ... on Episode {
                      id
                      episodeTitle
                      channelName
                    }
                    ... on External {
                      url
                      label
                    }
                  }
                }
                safety {
                  warnings
                  contraindications
                  interactions
                  notes
                }
                lastEditedAt
                createdAt
                updatedAt
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="CreateUserProtocol",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CreateUserProtocol.model_validate(data)

    async def update_user_protocol(
        self, input: UpdateUserProtocolInput, **kwargs: Any
    ) -> UpdateUserProtocol:
        query = gql(
            """
            mutation UpdateUserProtocol($input: UpdateUserProtocolInput!) {
              updateUserProtocol(input: $input) {
                id
                userId
                title
                goalType
                status
                sourceProtocolId
                stepsStructured {
                  label
                  timeOfDay
                  items {
                    type
                    refId
                    nameOverride
                    dosage
                    timing
                    notes
                    itemEntity {
                      __typename
                      ... on Product {
                        id
                        name
                        description
                      }
                      ... on Compound {
                        id
                        name
                        description
                      }
                    }
                  }
                }
                evidenceRefs {
                  type
                  refId
                  label
                  url
                  episodeId
                  timestamps
                  notes
                  evidenceRefEntity {
                    __typename
                    ... on Article {
                      id
                      title
                      articleSummary: summary
                    }
                    ... on CaseStudy {
                      id
                      title
                      summary
                    }
                    ... on Episode {
                      id
                      episodeTitle
                      channelName
                    }
                    ... on External {
                      url
                      label
                    }
                  }
                }
                safety {
                  warnings
                  contraindications
                  interactions
                  notes
                }
                lastEditedAt
                createdAt
                updatedAt
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query,
            operation_name="UpdateUserProtocol",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return UpdateUserProtocol.model_validate(data)

    async def delete_user_protocol(self, id: str, **kwargs: Any) -> DeleteUserProtocol:
        query = gql(
            """
            mutation DeleteUserProtocol($id: ID!) {
              deleteUserProtocol(id: $id)
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query,
            operation_name="DeleteUserProtocol",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return DeleteUserProtocol.model_validate(data)

    async def create_case_study(
        self, input: CaseStudyCreateWithOptionalIdsInput, **kwargs: Any
    ) -> CreateCaseStudy:
        query = gql(
            """
            mutation CreateCaseStudy($input: CaseStudyCreateWithOptionalIdsInput!) {
              createCaseStudy(input: $input) {
                id
                title
                summary
                url
                sourceType
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="CreateCaseStudy", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CreateCaseStudy.model_validate(data)

    async def update_case_study(
        self, input: CaseStudyUpdateWithOptionalIdsInput, **kwargs: Any
    ) -> UpdateCaseStudy:
        query = gql(
            """
            mutation UpdateCaseStudy($input: CaseStudyUpdateWithOptionalIdsInput!) {
              updateCaseStudy(input: $input) {
                id
                title
                summary
                url
                sourceType
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UpdateCaseStudy", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UpdateCaseStudy.model_validate(data)

    async def embed_business_description(
        self, business_id: str, **kwargs: Any
    ) -> EmbedBusinessDescription:
        query = gql(
            """
            mutation EmbedBusinessDescription($businessId: ID!) {
              embedBusinessDescription(businessId: $businessId) {
                id
                name
                description
              }
            }
            """
        )
        variables: dict[str, object] = {"businessId": business_id}
        response = await self.execute(
            query=query,
            operation_name="EmbedBusinessDescription",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return EmbedBusinessDescription.model_validate(data)

    async def save_entity(self, input: SaveEntityInput, **kwargs: Any) -> SaveEntity:
        query = gql(
            """
            mutation SaveEntity($input: SaveEntityInput!) {
              saveEntity(input: $input) {
                id
                userId
                targetType
                targetId
                note
                tags
                pinned
                source
                createdAt
                updatedAt
              }
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="SaveEntity", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return SaveEntity.model_validate(data)

    async def unsave_entity(
        self, input: UnsaveEntityInput, **kwargs: Any
    ) -> UnsaveEntity:
        query = gql(
            """
            mutation UnsaveEntity($input: UnsaveEntityInput!) {
              unsaveEntity(input: $input)
            }
            """
        )
        variables: dict[str, object] = {"input": input}
        response = await self.execute(
            query=query, operation_name="UnsaveEntity", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return UnsaveEntity.model_validate(data)

    async def me(self, **kwargs: Any) -> Me:
        query = gql(
            """
            query Me {
              me {
                id
                email
                name
                role
                profile {
                  id
                  userId
                  goals {
                    goalType
                    priority
                    notes
                  }
                  experienceLevel
                  dietStyle
                  avoidances
                  timeBudget
                  preferredFormats
                  topicInterests
                  entityPreferences {
                    likedEntityIds
                    hiddenEntityIds
                    blockedEntityIds
                  }
                  createdAt
                  updatedAt
                }
              }
            }
            """
        )
        variables: dict[str, object] = {}
        response = await self.execute(
            query=query, operation_name="Me", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Me.model_validate(data)

    async def my_profile(self, **kwargs: Any) -> MyProfile:
        query = gql(
            """
            query MyProfile {
              myProfile {
                id
                userId
                goals {
                  goalType
                  priority
                  notes
                }
                experienceLevel
                dietStyle
                avoidances
                timeBudget
                preferredFormats
                topicInterests
                entityPreferences {
                  likedEntityIds
                  hiddenEntityIds
                  blockedEntityIds
                }
                createdAt
                updatedAt
              }
            }
            """
        )
        variables: dict[str, object] = {}
        response = await self.execute(
            query=query, operation_name="MyProfile", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return MyProfile.model_validate(data)

    async def business(self, id: str, **kwargs: Any) -> Business:
        query = gql(
            """
            query Business($id: ID!) {
              business(id: $id) {
                id
                name
                description
                website
                mediaLinks {
                  url
                  description
                }
                products {
                  id
                  name
                  description
                }
                owners {
                  id
                  name
                  role
                }
                executives {
                  role
                  title
                  person {
                    id
                    name
                    role
                  }
                }
                sponsoredEpisodes {
                  id
                  episodeTitle
                  channelName
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Business", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Business.model_validate(data)

    async def businesses(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> Businesses:
        query = gql(
            """
            query Businesses($limit: Int, $offset: Int) {
              businesses(limit: $limit, offset: $offset) {
                id
                name
                description
                website
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="Businesses", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Businesses.model_validate(data)

    async def product(self, id: str, **kwargs: Any) -> Product:
        query = gql(
            """
            query Product($id: ID!) {
              product(id: $id) {
                id
                name
                description
                ingredients
                sourceUrl
                mediaLinks {
                  url
                  description
                }
                business {
                  id
                  name
                  description
                }
                compounds {
                  id
                  name
                  description
                }
                sponsorEpisodes {
                  id
                  episodeTitle
                  channelName
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Product", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Product.model_validate(data)

    async def products(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> Products:
        query = gql(
            """
            query Products($limit: Int, $offset: Int) {
              products(limit: $limit, offset: $offset) {
                id
                name
                description
                ingredients
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="Products", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Products.model_validate(data)

    async def person(self, id: str, **kwargs: Any) -> Person:
        query = gql(
            """
            query Person($id: ID!) {
              person(id: $id) {
                id
                name
                role
                bio
                mediaLinks {
                  url
                  description
                }
                businesses {
                  id
                  name
                  description
                }
                episodes {
                  id
                  episodeTitle
                  channelName
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Person", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Person.model_validate(data)

    async def people(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> People:
        query = gql(
            """
            query People($limit: Int, $offset: Int) {
              people(limit: $limit, offset: $offset) {
                id
                name
                role
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="People", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return People.model_validate(data)

    async def episode(self, id: str, **kwargs: Any) -> Episode:
        query = gql(
            """
            query Episode($id: ID!) {
              episode(id: $id) {
                id
                channelName
                episodeNumber
                episodeTitle
                episodeTranscriptUrl
                episodePageUrl
                webPageSummary
                webPageTimelines {
                  from
                  to
                  title
                  description
                }
                sponsorLinkObjects {
                  text
                  links
                  hasCodeDave
                  code
                  brand
                  discountPercent
                }
                takeaways
                s3TranscriptKey
                s3TranscriptUrl
                youtubeVideoId
                youtubeWatchUrl
                youtubeEmbedUrl
                mediaLinks {
                  url
                  description
                }
                publishedAt
                guests {
                  id
                  name
                  role
                }
                summaryShort
                summaryDetailed
                publishedSummary
                businessLinks
                sponsorBusinesses {
                  id
                  name
                  description
                }
                protocols {
                  id
                  name
                  description
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Episode", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Episode.model_validate(data)

    async def episodes(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> Episodes:
        query = gql(
            """
            query Episodes($limit: Int, $offset: Int) {
              episodes(limit: $limit, offset: $offset) {
                id
                episodeTitle
                channelName
                episodeNumber
                publishedAt
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="Episodes", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Episodes.model_validate(data)

    async def compound(self, id: str, **kwargs: Any) -> Compound:
        query = gql(
            """
            query Compound($id: ID!) {
              compound(id: $id) {
                id
                name
                description
                aliases
                mediaLinks {
                  url
                  description
                }
                products {
                  id
                  name
                  description
                }
                caseStudies {
                  id
                  title
                  summary
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Compound", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Compound.model_validate(data)

    async def compounds(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> Compounds:
        query = gql(
            """
            query Compounds($limit: Int, $offset: Int) {
              compounds(limit: $limit, offset: $offset) {
                id
                name
                description
                aliases
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="Compounds", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Compounds.model_validate(data)

    async def protocol(self, id: str, **kwargs: Any) -> Protocol:
        query = gql(
            """
            query Protocol($id: ID!) {
              protocol(id: $id) {
                id
                name
                description
                categories
                goals
                steps
                cautions
                aliases
                sourceUrl
                stepsStructured {
                  label
                  timeOfDay
                  items {
                    type
                    refId
                    nameOverride
                    dosage
                    timing
                    notes
                    itemEntity {
                      __typename
                      ... on Product {
                        id
                        name
                        description
                      }
                      ... on Compound {
                        id
                        name
                        description
                      }
                    }
                  }
                }
                evidenceRefs {
                  type
                  refId
                  label
                  url
                  episodeId
                  timestamps
                  notes
                  evidenceRefEntity {
                    __typename
                    ... on Article {
                      id
                      title
                      summary
                    }
                    ... on CaseStudy {
                      id
                      title
                      summary
                    }
                    ... on Episode {
                      id
                      episodeTitle
                      channelName
                    }
                    ... on External {
                      url
                      label
                    }
                  }
                }
                safety {
                  warnings
                  contraindications
                  interactions
                  notes
                }
                products {
                  id
                  name
                  description
                }
                compounds {
                  id
                  name
                  description
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="Protocol", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Protocol.model_validate(data)

    async def protocols(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> Protocols:
        query = gql(
            """
            query Protocols($limit: Int, $offset: Int) {
              protocols(limit: $limit, offset: $offset) {
                id
                name
                description
                categories
                goals
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="Protocols", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return Protocols.model_validate(data)

    async def case_study(self, id: str, **kwargs: Any) -> CaseStudy:
        query = gql(
            """
            query CaseStudy($id: ID!) {
              caseStudy(id: $id) {
                id
                title
                summary
                url
                sourceType
                mediaLinks {
                  url
                  description
                }
                episodes {
                  id
                  episodeTitle
                  channelName
                }
                compounds {
                  id
                  name
                  description
                }
                products {
                  id
                  name
                  description
                }
                protocols {
                  id
                  name
                  description
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="CaseStudy", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CaseStudy.model_validate(data)

    async def case_studies(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> CaseStudies:
        query = gql(
            """
            query CaseStudies($limit: Int, $offset: Int) {
              caseStudies(limit: $limit, offset: $offset) {
                id
                title
                summary
                url
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="CaseStudies", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CaseStudies.model_validate(data)

    async def vector_search_products(
        self, args: VectorSearchArgs, **kwargs: Any
    ) -> VectorSearchProducts:
        query = gql(
            """
            query VectorSearchProducts($args: VectorSearchArgs!) {
              vectorSearchProducts(args: $args) {
                id
                name
                description
                score
              }
            }
            """
        )
        variables: dict[str, object] = {"args": args}
        response = await self.execute(
            query=query,
            operation_name="VectorSearchProducts",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return VectorSearchProducts.model_validate(data)

    async def vector_search_businesses(
        self, args: VectorSearchArgs, **kwargs: Any
    ) -> VectorSearchBusinesses:
        query = gql(
            """
            query VectorSearchBusinesses($args: VectorSearchArgs!) {
              vectorSearchBusinesses(args: $args) {
                id
                name
                description
                score
              }
            }
            """
        )
        variables: dict[str, object] = {"args": args}
        response = await self.execute(
            query=query,
            operation_name="VectorSearchBusinesses",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return VectorSearchBusinesses.model_validate(data)

    async def vector_search_people(
        self, args: VectorSearchArgs, **kwargs: Any
    ) -> VectorSearchPeople:
        query = gql(
            """
            query VectorSearchPeople($args: VectorSearchArgs!) {
              vectorSearchPeople(args: $args) {
                id
                name
                bio
                score
              }
            }
            """
        )
        variables: dict[str, object] = {"args": args}
        response = await self.execute(
            query=query,
            operation_name="VectorSearchPeople",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return VectorSearchPeople.model_validate(data)

    async def saved_entities(
        self,
        filter: Union[Optional[SavedEntitiesFilterInput], UnsetType] = UNSET,
        page: Union[Optional[CursorPageInput], UnsetType] = UNSET,
        **kwargs: Any
    ) -> SavedEntities:
        query = gql(
            """
            query SavedEntities($filter: SavedEntitiesFilterInput, $page: CursorPageInput) {
              savedEntities(filter: $filter, page: $page) {
                edges {
                  cursor
                  node {
                    id
                    userId
                    targetType
                    targetId
                    note
                    tags
                    pinned
                    source
                    createdAt
                    updatedAt
                    target {
                      __typename
                      ... on Product {
                        id
                        name
                        description
                      }
                      ... on Compound {
                        id
                        name
                        description
                      }
                      ... on CaseStudy {
                        id
                        title
                        summary
                      }
                      ... on Protocol {
                        id
                        name
                        description
                      }
                      ... on Person {
                        id
                        name
                        role
                      }
                      ... on Business {
                        id
                        name
                        description
                      }
                      ... on Episode {
                        id
                        episodeTitle
                        channelName
                      }
                      ... on Article {
                        id
                        title
                        summary
                      }
                    }
                  }
                }
                pageInfo {
                  hasNextPage
                  endCursor
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"filter": filter, "page": page}
        response = await self.execute(
            query=query, operation_name="SavedEntities", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return SavedEntities.model_validate(data)

    async def my_user_protocols(
        self,
        filter: Union[Optional[UserProtocolsFilterInput], UnsetType] = UNSET,
        page: Union[Optional[CursorPageInput], UnsetType] = UNSET,
        **kwargs: Any
    ) -> MyUserProtocols:
        query = gql(
            """
            query MyUserProtocols($filter: UserProtocolsFilterInput, $page: CursorPageInput) {
              myUserProtocols(filter: $filter, page: $page) {
                edges {
                  cursor
                  node {
                    id
                    userId
                    title
                    goalType
                    status
                    sourceProtocolId
                    stepsStructured {
                      label
                      timeOfDay
                      items {
                        type
                        refId
                        nameOverride
                        dosage
                        timing
                        notes
                        itemEntity {
                          __typename
                          ... on Product {
                            id
                            name
                            description
                          }
                          ... on Compound {
                            id
                            name
                            description
                          }
                        }
                      }
                    }
                    evidenceRefs {
                      type
                      refId
                      label
                      url
                      episodeId
                      timestamps
                      notes
                      evidenceRefEntity {
                        __typename
                        ... on Article {
                          id
                          title
                          summary
                        }
                        ... on CaseStudy {
                          id
                          title
                          summary
                        }
                        ... on Episode {
                          id
                          episodeTitle
                          channelName
                        }
                        ... on External {
                          url
                          label
                        }
                      }
                    }
                    safety {
                      warnings
                      contraindications
                      interactions
                      notes
                    }
                    lastEditedAt
                    createdAt
                    updatedAt
                  }
                }
                pageInfo {
                  hasNextPage
                  endCursor
                }
              }
            }
            """
        )
        variables: dict[str, object] = {"filter": filter, "page": page}
        response = await self.execute(
            query=query, operation_name="MyUserProtocols", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return MyUserProtocols.model_validate(data)

    async def all_users(
        self,
        limit: Union[Optional[int], UnsetType] = UNSET,
        offset: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> AllUsers:
        query = gql(
            """
            query AllUsers($limit: Int, $offset: Int) {
              allUsers(limit: $limit, offset: $offset) {
                id
                email
                name
                role
              }
            }
            """
        )
        variables: dict[str, object] = {"limit": limit, "offset": offset}
        response = await self.execute(
            query=query, operation_name="AllUsers", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return AllUsers.model_validate(data)



# Generated by ariadne-codegen
# Source: ../../src/graphql/schema.graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    CaseStudySourceType,
    DietStyle,
    EvidenceRefType,
    ExperienceLevel,
    GoalType,
    PreferredFormat,
    ProtocolCategory,
    ProtocolStepItemType,
    ProtocolTimeOfDay,
    SavedEntityType,
    SaveSource,
    TimeBudget,
    UserGoalType,
    UserProtocolStatus,
    UserProvider,
    UserRole,
)


class ProtocolStepItemInput(BaseModel):
    type: ProtocolStepItemType
    ref_id: Optional[str] = Field(alias="refId", default=None)
    name_override: Optional[str] = Field(alias="nameOverride", default=None)
    dosage: Optional[str] = None
    timing: Optional[str] = None
    notes: Optional[str] = None


class CursorPageInput(BaseModel):
    """Cursor pagination input (matches your usage: first + after)"""

    first: int
    after: Optional[str] = None


class ProtocolStepGroupInput(BaseModel):
    label: Optional[str] = None
    time_of_day: Optional[ProtocolTimeOfDay] = Field(alias="timeOfDay", default=None)
    items: list["ProtocolStepItemInput"]


class EvidenceRefInput(BaseModel):
    type: EvidenceRefType
    ref_id: Optional[str] = Field(alias="refId", default=None)
    label: Optional[str] = None
    url: Optional[str] = None
    episode_id: Optional[str] = Field(alias="episodeId", default=None)
    timestamps: Optional[list[int]] = None
    notes: Optional[str] = None


class SafetyBucketInput(BaseModel):
    warnings: Optional[list[str]] = None
    contraindications: Optional[list[str]] = None
    interactions: Optional[list[str]] = None
    notes: Optional[str] = None


class CreateUserProtocolInput(BaseModel):
    title: str
    goal_type: Optional[UserGoalType] = Field(alias="goalType", default=None)
    status: Optional[UserProtocolStatus] = None
    source_protocol_id: Optional[str] = Field(alias="sourceProtocolId", default=None)
    steps_structured: Optional[list["ProtocolStepGroupInput"]] = Field(
        alias="stepsStructured", default=None
    )
    evidence_refs: Optional[list["EvidenceRefInput"]] = Field(
        alias="evidenceRefs", default=None
    )
    safety: Optional["SafetyBucketInput"] = None


class UpdateUserProtocolInput(BaseModel):
    id: str
    title: Optional[str] = None
    goal_type: Optional[UserGoalType] = Field(alias="goalType", default=None)
    status: Optional[UserProtocolStatus] = None
    steps_structured: Optional[list["ProtocolStepGroupInput"]] = Field(
        alias="stepsStructured", default=None
    )
    evidence_refs: Optional[list["EvidenceRefInput"]] = Field(
        alias="evidenceRefs", default=None
    )
    safety: Optional["SafetyBucketInput"] = None


class UserGoalInput(BaseModel):
    goal_type: GoalType = Field(alias="goalType")
    priority: int
    notes: Optional[str] = None


class EntityPreferencesInput(BaseModel):
    liked_entity_ids: Optional[list[str]] = Field(alias="likedEntityIds", default=None)
    hidden_entity_ids: Optional[list[str]] = Field(
        alias="hiddenEntityIds", default=None
    )
    blocked_entity_ids: Optional[list[str]] = Field(
        alias="blockedEntityIds", default=None
    )


class UserProfileUpsertInput(BaseModel):
    user_id: str = Field(alias="userId")
    goals: Optional[list["UserGoalInput"]] = None
    experience_level: Optional[ExperienceLevel] = Field(
        alias="experienceLevel", default=None
    )
    diet_style: Optional[DietStyle] = Field(alias="dietStyle", default=None)
    avoidances: Optional[list[str]] = None
    time_budget: Optional[TimeBudget] = Field(alias="timeBudget", default=None)
    preferred_formats: Optional[list[PreferredFormat]] = Field(
        alias="preferredFormats", default=None
    )
    topic_interests: Optional[list[str]] = Field(alias="topicInterests", default=None)
    entity_preferences: Optional["EntityPreferencesInput"] = Field(
        alias="entityPreferences", default=None
    )


class MediaLinkInput(BaseModel):
    url: str
    description: str
    poster_url: Optional[str] = Field(alias="posterUrl", default=None)


class UserUpsertInput(BaseModel):
    user_id: Optional[str] = Field(alias="userId", default=None)
    email: str
    password: Optional[str] = None
    provider: Optional[UserProvider] = None
    provider_id: Optional[str] = Field(alias="providerId", default=None)
    name: Optional[str] = None
    role: Optional[UserRole] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class UserCreateInput(BaseModel):
    email: str
    password: Optional[str] = None
    provider: Optional[UserProvider] = None
    provider_id: Optional[str] = Field(alias="providerId", default=None)
    name: Optional[str] = None
    role: Optional[UserRole] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class BusinessCreateRelationsInput(BaseModel):
    name: str
    description: Optional[str] = None
    biography: Optional[str] = None
    website: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    owner_ids: Optional[list[str]] = Field(alias="ownerIds", default=None)
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)
    sponsor_episode_ids: Optional[list[str]] = Field(
        alias="sponsorEpisodeIds", default=None
    )
    owners_nested: Optional[list["BusinessOwnerNestedInput"]] = Field(
        alias="ownersNested", default=None
    )
    executives_nested: Optional[list["BusinessExecutiveNestedInput"]] = Field(
        alias="executivesNested", default=None
    )
    products_nested: Optional[list["BusinessProductNestedInput"]] = Field(
        alias="productsNested", default=None
    )
    sponsor_episodes_nested: Optional[list["BusinessEpisodeNestedInput"]] = Field(
        alias="sponsorEpisodesNested", default=None
    )
    executives: Optional[list["BusinessExecutiveRelationInput"]] = None


class BusinessUpdateWithIdsInput(BaseModel):
    id: str
    name: Optional[str] = None
    description: Optional[str] = None
    website: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    owner_ids: Optional[list[str]] = Field(alias="ownerIds", default=None)
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)
    sponsor_episode_ids: Optional[list[str]] = Field(
        alias="sponsorEpisodeIds", default=None
    )


class BusinessOwnerNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    role: Optional[str] = None
    bio: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class BusinessProductNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    ingredients: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)


class BusinessExecutiveRelationInput(BaseModel):
    person_id: str = Field(alias="personId")
    title: Optional[str] = None
    role: Optional[str] = None


class SponsorLinkObjectInput(BaseModel):
    text: Optional[str] = None
    links: Optional[list[str]] = None
    has_code_dave: Optional[bool] = Field(alias="hasCodeDave", default=None)
    code: Optional[str] = None
    brand: Optional[str] = None
    discount_percent: Optional[float] = Field(alias="discountPercent", default=None)


class WebPageTimelineInput(BaseModel):
    from_: str = Field(alias="from")
    to: str
    title: Optional[str] = None
    description: Optional[str] = None


class BusinessEpisodeNestedInput(BaseModel):
    id: Optional[str] = None
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber", default=None)
    episode_page_url: str = Field(alias="episodePageUrl")
    episode_title: Optional[str] = Field(alias="episodeTitle", default=None)
    published_at: Optional[Any] = Field(alias="publishedAt", default=None)
    summary_short: Optional[str] = Field(alias="summaryShort", default=None)
    web_page_summary: Optional[str] = Field(alias="webPageSummary", default=None)
    summary_detailed: Optional[str] = Field(alias="summaryDetailed", default=None)
    youtube_video_id: Optional[str] = Field(alias="youtubeVideoId", default=None)
    youtube_watch_url: Optional[str] = Field(alias="youtubeWatchUrl", default=None)
    youtube_embed_url: Optional[str] = Field(alias="youtubeEmbedUrl", default=None)
    takeaways: Optional[list[str]] = None
    s_3_transcript_key: Optional[str] = Field(alias="s3TranscriptKey", default=None)
    s_3_transcript_url: Optional[str] = Field(alias="s3TranscriptUrl", default=None)
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    sponsor_link_objects: Optional[list["SponsorLinkObjectInput"]] = Field(
        alias="sponsorLinkObjects", default=None
    )
    web_page_timelines: Optional[list["WebPageTimelineInput"]] = Field(
        alias="webPageTimelines", default=None
    )


class BusinessExecutiveNestedInput(BaseModel):
    name: str
    title: str
    role: str
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class BusinessUpdateRelationFieldsInput(BaseModel):
    id: str
    name: Optional[str] = None
    description: Optional[str] = None
    website: Optional[str] = None
    biography: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    owner_ids: Optional[list[str]] = Field(alias="ownerIds", default=None)
    owners_nested: Optional[list["BusinessOwnerNestedInput"]] = Field(
        alias="ownersNested", default=None
    )
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)
    products_nested: Optional[list["BusinessProductNestedInput"]] = Field(
        alias="productsNested", default=None
    )
    executives: Optional[list["BusinessExecutiveRelationInput"]] = None
    executives_nested: Optional[list["BusinessExecutiveNestedInput"]] = Field(
        alias="executivesNested", default=None
    )
    sponsor_episode_ids: Optional[list[str]] = Field(
        alias="sponsorEpisodeIds", default=None
    )
    sponsor_episodes_nested: Optional[list["BusinessEpisodeNestedInput"]] = Field(
        alias="sponsorEpisodesNested", default=None
    )


class ProductCreateWithIdsInput(BaseModel):
    name: str
    business_id: str = Field(alias="businessId")
    description: Optional[str] = None
    price: Optional[float] = None
    ingredients: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)
    protocol_ids: Optional[list[str]] = Field(alias="protocolIds", default=None)


class ProductUpdateWithIdsInput(BaseModel):
    id: str
    name: Optional[str] = None
    description: Optional[str] = None
    price: Optional[float] = None
    ingredients: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)
    protocol_ids: Optional[list[str]] = Field(alias="protocolIds", default=None)


class ProductCompoundNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    aliases: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class ProductProtocolNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    categories: Optional[list[ProtocolCategory]] = None
    goals: Optional[list[str]] = None
    steps: Optional[list[str]] = None
    cautions: Optional[list[str]] = None
    aliases: Optional[list[str]] = None
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)


class ProductUpdateRelationFieldsInput(BaseModel):
    id: str
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)
    compounds_nested: Optional[list["ProductCompoundNestedInput"]] = Field(
        alias="compoundsNested", default=None
    )
    protocol_ids: Optional[list[str]] = Field(alias="protocolIds", default=None)
    protocols_nested: Optional[list["ProductProtocolNestedInput"]] = Field(
        alias="protocolsNested", default=None
    )


class PersonCreateInput(BaseModel):
    name: str
    role: Optional[str] = None
    bio: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class PersonUpdateInput(BaseModel):
    id: str
    name: Optional[str] = None
    role: Optional[str] = None
    bio: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class EpisodeCreateWithIdsInput(BaseModel):
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber", default=None)
    episode_title: Optional[str] = Field(alias="episodeTitle", default=None)
    episode_page_url: str = Field(alias="episodePageUrl")
    episode_transcript_url: Optional[str] = Field(
        alias="episodeTranscriptUrl", default=None
    )
    published_at: Optional[Any] = Field(alias="publishedAt", default=None)
    summary_short: Optional[str] = Field(alias="summaryShort", default=None)
    web_page_summary: Optional[str] = Field(alias="webPageSummary", default=None)
    summary_detailed: Optional[str] = Field(alias="summaryDetailed", default=None)
    published_summary: Optional[str] = Field(alias="publishedSummary", default=None)
    youtube_video_id: Optional[str] = Field(alias="youtubeVideoId", default=None)
    youtube_watch_url: Optional[str] = Field(alias="youtubeWatchUrl", default=None)
    youtube_embed_url: Optional[str] = Field(alias="youtubeEmbedUrl", default=None)
    takeaways: Optional[list[str]] = None
    s_3_transcript_key: Optional[str] = Field(alias="s3TranscriptKey", default=None)
    s_3_transcript_url: Optional[str] = Field(alias="s3TranscriptUrl", default=None)
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    sponsor_link_objects: Optional[list["SponsorLinkObjectInput"]] = Field(
        alias="sponsorLinkObjects", default=None
    )
    web_page_timelines: Optional[list["WebPageTimelineInput"]] = Field(
        alias="webPageTimelines", default=None
    )
    business_links: Optional[list[str]] = Field(alias="businessLinks", default=None)
    guest_ids: Optional[list[str]] = Field(alias="guestIds", default=None)
    sponsor_business_ids: Optional[list[str]] = Field(
        alias="sponsorBusinessIds", default=None
    )
    protocol_ids: Optional[list[str]] = Field(alias="protocolIds", default=None)


class EpisodeUpdateWithIdsInput(BaseModel):
    id: str
    channel_name: Optional[str] = Field(alias="channelName", default=None)
    episode_number: Optional[int] = Field(alias="episodeNumber", default=None)
    episode_title: Optional[str] = Field(alias="episodeTitle", default=None)
    episode_page_url: Optional[str] = Field(alias="episodePageUrl", default=None)
    episode_transcript_url: Optional[str] = Field(
        alias="episodeTranscriptUrl", default=None
    )
    published_at: Optional[Any] = Field(alias="publishedAt", default=None)
    summary_short: Optional[str] = Field(alias="summaryShort", default=None)
    web_page_summary: Optional[str] = Field(alias="webPageSummary", default=None)
    summary_detailed: Optional[str] = Field(alias="summaryDetailed", default=None)
    published_summary: Optional[str] = Field(alias="publishedSummary", default=None)
    youtube_video_id: Optional[str] = Field(alias="youtubeVideoId", default=None)
    youtube_watch_url: Optional[str] = Field(alias="youtubeWatchUrl", default=None)
    youtube_embed_url: Optional[str] = Field(alias="youtubeEmbedUrl", default=None)
    takeaways: Optional[list[str]] = None
    s_3_transcript_key: Optional[str] = Field(alias="s3TranscriptKey", default=None)
    s_3_transcript_url: Optional[str] = Field(alias="s3TranscriptUrl", default=None)
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    sponsor_link_objects: Optional[list["SponsorLinkObjectInput"]] = Field(
        alias="sponsorLinkObjects", default=None
    )
    web_page_timelines: Optional[list["WebPageTimelineInput"]] = Field(
        alias="webPageTimelines", default=None
    )
    business_links: Optional[list[str]] = Field(alias="businessLinks", default=None)
    guest_ids: Optional[list[str]] = Field(alias="guestIds", default=None)
    sponsor_business_ids: Optional[list[str]] = Field(
        alias="sponsorBusinessIds", default=None
    )
    protocol_ids: Optional[list[str]] = Field(alias="protocolIds", default=None)


class EpisodeGuestNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    role: Optional[str] = None
    bio: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class EpisodeSponsorBusinessNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    website: Optional[str] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class EpisodeUpdateRelationFieldsInput(BaseModel):
    id: str
    guest_ids: Optional[list[str]] = Field(alias="guestIds", default=None)
    guests_nested: Optional[list["EpisodeGuestNestedInput"]] = Field(
        alias="guestsNested", default=None
    )
    sponsor_business_ids: Optional[list[str]] = Field(
        alias="sponsorBusinessIds", default=None
    )
    sponsor_businesses_nested: Optional[list["EpisodeSponsorBusinessNestedInput"]] = (
        Field(alias="sponsorBusinessesNested", default=None)
    )
    protocol_ids: Optional[list[str]] = Field(alias="protocolIds", default=None)


class ProtocolCreateWithIdsInput(BaseModel):
    name: str
    description: Optional[str] = None
    categories: Optional[list[ProtocolCategory]] = None
    goals: Optional[list[str]] = None
    steps: Optional[list[str]] = None
    cautions: Optional[list[str]] = None
    aliases: Optional[list[str]] = None
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)


class ProtocolUpdateWithIdsInput(BaseModel):
    id: str
    name: Optional[str] = None
    description: Optional[str] = None
    categories: Optional[list[ProtocolCategory]] = None
    goals: Optional[list[str]] = None
    steps: Optional[list[str]] = None
    cautions: Optional[list[str]] = None
    aliases: Optional[list[str]] = None
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)
    steps_structured: Optional[list["ProtocolStepGroupInput"]] = Field(
        alias="stepsStructured", default=None
    )
    evidence_refs: Optional[list["EvidenceRefInput"]] = Field(
        alias="evidenceRefs", default=None
    )
    safety: Optional["SafetyBucketInput"] = None
    overwrite_evidence_refs: Optional[bool] = Field(
        alias="overwriteEvidenceRefs", default=None
    )
    add_to_evidence_refs: Optional[bool] = Field(
        alias="addToEvidenceRefs", default=None
    )


class ProtocolProductNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    business_id: Optional[str] = Field(alias="businessId", default=None)
    ingredients: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)


class ProtocolCompoundNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    aliases: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )


class ProtocolUpdateRelationFieldsInput(BaseModel):
    id: str
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)
    products_nested: Optional[list["ProtocolProductNestedInput"]] = Field(
        alias="productsNested", default=None
    )
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)
    compounds_nested: Optional[list["ProtocolCompoundNestedInput"]] = Field(
        alias="compoundsNested", default=None
    )


class CompoundCreateWithIdsInput(BaseModel):
    name: str
    description: Optional[str] = None
    aliases: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)


class CompoundUpdateWithIdsInput(BaseModel):
    id: str
    name: Optional[str] = None
    description: Optional[str] = None
    aliases: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)


class CompoundProductNestedInput(BaseModel):
    id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    ingredients: Optional[list[str]] = None
    media_links: Optional[list["MediaLinkInput"]] = Field(
        alias="mediaLinks", default=None
    )
    source_url: Optional[str] = Field(alias="sourceUrl", default=None)


class CompoundUpdateRelationFieldsInput(BaseModel):
    id: str
    product_ids: Optional[list[str]] = Field(alias="productIds", default=None)
    products_nested: Optional[list["CompoundProductNestedInput"]] = Field(
        alias="productsNested", default=None
    )


class CaseStudyCreateWithOptionalIdsInput(BaseModel):
    title: str
    summary: str
    url: Optional[str] = None
    source_type: Optional[CaseStudySourceType] = Field(alias="sourceType", default=None)
    episode_ids: Optional[list[str]] = Field(alias="episodeIds", default=None)
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)


class CaseStudyUpdateWithOptionalIdsInput(BaseModel):
    id: str
    title: Optional[str] = None
    summary: Optional[str] = None
    url: Optional[str] = None
    source_type: Optional[CaseStudySourceType] = Field(alias="sourceType", default=None)
    episode_ids: Optional[list[str]] = Field(alias="episodeIds", default=None)
    compound_ids: Optional[list[str]] = Field(alias="compoundIds", default=None)


class UserProtocolsFilterInput(BaseModel):
    """Filter input for user protocols listing"""

    status: Optional[UserProtocolStatus] = None
    goal_type: Optional[UserGoalType] = Field(alias="goalType", default=None)
    search: Optional[str] = None


class SaveEntityInput(BaseModel):
    target_type: SavedEntityType = Field(alias="targetType")
    target_id: str = Field(alias="targetId")
    note: Optional[str] = None
    tags: Optional[list[str]] = None
    pinned: Optional[bool] = None
    source: Optional[SaveSource] = None


class UnsaveEntityInput(BaseModel):
    target_type: SavedEntityType = Field(alias="targetType")
    target_id: str = Field(alias="targetId")


class SavedEntitiesFilterInput(BaseModel):
    target_type: Optional[SavedEntityType] = Field(alias="targetType", default=None)
    search: Optional[str] = None
    tags: Optional[list[str]] = None
    pinned: Optional[bool] = None


class VectorSearchArgs(BaseModel):
    query: str
    num_candidates: Optional[int] = Field(alias="numCandidates", default=None)
    limit: Optional[int] = None


ProtocolStepGroupInput.model_rebuild()
CreateUserProtocolInput.model_rebuild()
UpdateUserProtocolInput.model_rebuild()
UserProfileUpsertInput.model_rebuild()
UserUpsertInput.model_rebuild()
UserCreateInput.model_rebuild()
BusinessCreateRelationsInput.model_rebuild()
BusinessUpdateWithIdsInput.model_rebuild()
BusinessOwnerNestedInput.model_rebuild()
BusinessProductNestedInput.model_rebuild()
BusinessEpisodeNestedInput.model_rebuild()
BusinessExecutiveNestedInput.model_rebuild()
BusinessUpdateRelationFieldsInput.model_rebuild()
ProductCreateWithIdsInput.model_rebuild()
ProductUpdateWithIdsInput.model_rebuild()
ProductCompoundNestedInput.model_rebuild()
ProductUpdateRelationFieldsInput.model_rebuild()
PersonCreateInput.model_rebuild()
PersonUpdateInput.model_rebuild()
EpisodeCreateWithIdsInput.model_rebuild()
EpisodeUpdateWithIdsInput.model_rebuild()
EpisodeGuestNestedInput.model_rebuild()
EpisodeSponsorBusinessNestedInput.model_rebuild()
EpisodeUpdateRelationFieldsInput.model_rebuild()
ProtocolUpdateWithIdsInput.model_rebuild()
ProtocolProductNestedInput.model_rebuild()
ProtocolCompoundNestedInput.model_rebuild()
ProtocolUpdateRelationFieldsInput.model_rebuild()
CompoundCreateWithIdsInput.model_rebuild()
CompoundUpdateWithIdsInput.model_rebuild()
CompoundProductNestedInput.model_rebuild()
CompoundUpdateRelationFieldsInput.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteProtocol(BaseModel):
    delete_protocol: "DeleteProtocolDeleteProtocol" = Field(alias="deleteProtocol")


class DeleteProtocolDeleteProtocol(BaseModel):
    id: str
    name: str


DeleteProtocol.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class VectorSearchBusinesses(BaseModel):
    vector_search_businesses: Optional[
        list["VectorSearchBusinessesVectorSearchBusinesses"]
    ] = Field(alias="vectorSearchBusinesses")


class VectorSearchBusinessesVectorSearchBusinesses(BaseModel):
    id: str
    name: str
    description: str
    score: Optional[float]


VectorSearchBusinesses.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class DeleteEpisode(BaseModel):
    delete_episode: Optional["DeleteEpisodeDeleteEpisode"] = Field(
        alias="deleteEpisode"
    )


class DeleteEpisodeDeleteEpisode(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")


DeleteEpisode.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpsertUser(BaseModel):
    upsert_user: "UpsertUserUpsertUser" = Field(alias="upsertUser")


class UpsertUserUpsertUser(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


UpsertUser.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CaseStudies(BaseModel):
    case_studies: list["CaseStudiesCaseStudies"] = Field(alias="caseStudies")


class CaseStudiesCaseStudies(BaseModel):
    id: str
    title: str
    summary: str
    url: Optional[str]


CaseStudies.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class UnsaveEntity(BaseModel):
    unsave_entity: bool = Field(alias="unsaveEntity")



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel
from .enums import ProtocolCategory


class Protocols(BaseModel):
    protocols: list["ProtocolsProtocols"]


class ProtocolsProtocols(BaseModel):
    id: str
    name: str
    description: Optional[str]
    categories: list[ProtocolCategory]
    goals: list[str]


Protocols.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class Register(BaseModel):
    register: "RegisterRegister"


class RegisterRegister(BaseModel):
    token: str
    user: "RegisterRegisterUser"


class RegisterRegisterUser(BaseModel):
    id: str
    email: str
    name: Optional[str]
    role: str


Register.model_rebuild()
RegisterRegister.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from pydantic import Field

from .base_model import BaseModel


class DeleteProduct(BaseModel):
    delete_product: "DeleteProductDeleteProduct" = Field(alias="deleteProduct")


class DeleteProductDeleteProduct(BaseModel):
    id: str
    name: str


DeleteProduct.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class Episodes(BaseModel):
    episodes: list["EpisodesEpisodes"]


class EpisodesEpisodes(BaseModel):
    id: str
    episode_title: Optional[str] = Field(alias="episodeTitle")
    channel_name: str = Field(alias="channelName")
    episode_number: Optional[int] = Field(alias="episodeNumber")
    published_at: Optional[Any] = Field(alias="publishedAt")


Episodes.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateBusiness(BaseModel):
    update_business: Optional["UpdateBusinessUpdateBusiness"] = Field(
        alias="updateBusiness"
    )


class UpdateBusinessUpdateBusiness(BaseModel):
    id: str
    name: str
    description: Optional[str]
    website: Optional[str]


UpdateBusiness.model_rebuild()



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateCompound(BaseModel):
    create_compound: "CreateCompoundCreateCompound" = Field(alias="createCompound")


class CreateCompoundCreateCompound(BaseModel):
    id: str
    name: str
    description: Optional[str]
    aliases: list[str]


CreateCompound.model_rebuild()



# Generated by ariadne-codegen

from .all_users import AllUsers, AllUsersAllUsers
from .async_base_client import AsyncBaseClient
from .base_model import BaseModel, Upload
from .business import (
    Business,
    BusinessBusiness,
    BusinessBusinessExecutives,
    BusinessBusinessExecutivesPerson,
    BusinessBusinessMediaLinks,
    BusinessBusinessOwners,
    BusinessBusinessProducts,
    BusinessBusinessSponsoredEpisodes,
)
from .businesses import Businesses, BusinessesBusinesses
from .case_studies import CaseStudies, CaseStudiesCaseStudies
from .case_study import (
    CaseStudy,
    CaseStudyCaseStudy,
    CaseStudyCaseStudyCompounds,
    CaseStudyCaseStudyEpisodes,
    CaseStudyCaseStudyMediaLinks,
    CaseStudyCaseStudyProducts,
    CaseStudyCaseStudyProtocols,
)
from .client import Client
from .compound import (
    Compound,
    CompoundCompound,
    CompoundCompoundCaseStudies,
    CompoundCompoundMediaLinks,
    CompoundCompoundProducts,
)
from .compounds import Compounds, CompoundsCompounds
from .create_business_with_relations import (
    CreateBusinessWithRelations,
    CreateBusinessWithRelationsCreateBusinessWithRelations,
)
from .create_case_study import CreateCaseStudy, CreateCaseStudyCreateCaseStudy
from .create_compound import CreateCompound, CreateCompoundCreateCompound
from .create_episode import CreateEpisode, CreateEpisodeCreateEpisode
from .create_person import CreatePerson, CreatePersonCreatePerson
from .create_product import CreateProduct, CreateProductCreateProduct
from .create_protocol import CreateProtocol, CreateProtocolCreateProtocol
from .create_user_protocol import (
    CreateUserProtocol,
    CreateUserProtocolCreateUserProtocol,
    CreateUserProtocolCreateUserProtocolEvidenceRefs,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityArticle,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityEpisode,
    CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityExternal,
    CreateUserProtocolCreateUserProtocolSafety,
    CreateUserProtocolCreateUserProtocolStepsStructured,
    CreateUserProtocolCreateUserProtocolStepsStructuredItems,
    CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityCompound,
    CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityProduct,
)
from .delete_all_episodes import DeleteAllEpisodes, DeleteAllEpisodesDeleteAllEpisodes
from .delete_business import DeleteBusiness, DeleteBusinessDeleteBusiness
from .delete_compound import DeleteCompound, DeleteCompoundDeleteCompound
from .delete_episode import DeleteEpisode, DeleteEpisodeDeleteEpisode
from .delete_person import DeletePerson, DeletePersonDeletePerson
from .delete_product import DeleteProduct, DeleteProductDeleteProduct
from .delete_protocol import DeleteProtocol, DeleteProtocolDeleteProtocol
from .delete_user import DeleteUser, DeleteUserDeleteUser
from .delete_user_profile import DeleteUserProfile, DeleteUserProfileDeleteUserProfile
from .delete_user_protocol import DeleteUserProtocol
from .embed_business_description import (
    EmbedBusinessDescription,
    EmbedBusinessDescriptionEmbedBusinessDescription,
)
from .embed_person_bio import EmbedPersonBio, EmbedPersonBioEmbedPersonBio
from .embed_product_description import (
    EmbedProductDescription,
    EmbedProductDescriptionEmbedProductDescription,
)
from .enums import (
    ArticleSourceType,
    CaseStudySourceType,
    DietStyle,
    EvidenceRefType,
    ExperienceLevel,
    GoalType,
    PreferredFormat,
    ProtocolCategory,
    ProtocolStepItemType,
    ProtocolTimeOfDay,
    SavedEntityType,
    SaveSource,
    TimeBudget,
    UserGoalType,
    UserProtocolStatus,
    UserProvider,
    UserRole,
)
from .episode import (
    Episode,
    EpisodeEpisode,
    EpisodeEpisodeGuests,
    EpisodeEpisodeMediaLinks,
    EpisodeEpisodeProtocols,
    EpisodeEpisodeSponsorBusinesses,
    EpisodeEpisodeSponsorLinkObjects,
    EpisodeEpisodeWebPageTimelines,
)
from .episodes import Episodes, EpisodesEpisodes
from .exceptions import (
    GraphQLClientError,
    GraphQLClientGraphQLError,
    GraphQLClientGraphQLMultiError,
    GraphQLClientHttpError,
    GraphQLClientInvalidResponseError,
)
from .input_types import (
    BusinessCreateRelationsInput,
    BusinessEpisodeNestedInput,
    BusinessExecutiveNestedInput,
    BusinessExecutiveRelationInput,
    BusinessOwnerNestedInput,
    BusinessProductNestedInput,
    BusinessUpdateRelationFieldsInput,
    BusinessUpdateWithIdsInput,
    CaseStudyCreateWithOptionalIdsInput,
    CaseStudyUpdateWithOptionalIdsInput,
    CompoundCreateWithIdsInput,
    CompoundProductNestedInput,
    CompoundUpdateRelationFieldsInput,
    CompoundUpdateWithIdsInput,
    CreateUserProtocolInput,
    CursorPageInput,
    EntityPreferencesInput,
    EpisodeCreateWithIdsInput,
    EpisodeGuestNestedInput,
    EpisodeSponsorBusinessNestedInput,
    EpisodeUpdateRelationFieldsInput,
    EpisodeUpdateWithIdsInput,
    EvidenceRefInput,
    MediaLinkInput,
    PersonCreateInput,
    PersonUpdateInput,
    ProductCompoundNestedInput,
    ProductCreateWithIdsInput,
    ProductProtocolNestedInput,
    ProductUpdateRelationFieldsInput,
    ProductUpdateWithIdsInput,
    ProtocolCompoundNestedInput,
    ProtocolCreateWithIdsInput,
    ProtocolProductNestedInput,
    ProtocolStepGroupInput,
    ProtocolStepItemInput,
    ProtocolUpdateRelationFieldsInput,
    ProtocolUpdateWithIdsInput,
    SafetyBucketInput,
    SavedEntitiesFilterInput,
    SaveEntityInput,
    SponsorLinkObjectInput,
    UnsaveEntityInput,
    UpdateUserProtocolInput,
    UserCreateInput,
    UserGoalInput,
    UserProfileUpsertInput,
    UserProtocolsFilterInput,
    UserUpsertInput,
    VectorSearchArgs,
    WebPageTimelineInput,
)
from .login import Login, LoginLogin, LoginLoginUser
from .me import Me, MeMe, MeMeProfile, MeMeProfileEntityPreferences, MeMeProfileGoals
from .my_profile import (
    MyProfile,
    MyProfileMyProfile,
    MyProfileMyProfileEntityPreferences,
    MyProfileMyProfileGoals,
)
from .my_user_protocols import (
    MyUserProtocols,
    MyUserProtocolsMyUserProtocols,
    MyUserProtocolsMyUserProtocolsEdges,
    MyUserProtocolsMyUserProtocolsEdgesNode,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefs,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityArticle,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityCaseStudy,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityEpisode,
    MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityExternal,
    MyUserProtocolsMyUserProtocolsEdgesNodeSafety,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructured,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItems,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityCompound,
    MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityProduct,
    MyUserProtocolsMyUserProtocolsPageInfo,
)
from .people import People, PeoplePeople
from .person import (
    Person,
    PersonPerson,
    PersonPersonBusinesses,
    PersonPersonEpisodes,
    PersonPersonMediaLinks,
)
from .product import (
    Product,
    ProductProduct,
    ProductProductBusiness,
    ProductProductCompounds,
    ProductProductMediaLinks,
    ProductProductSponsorEpisodes,
)
from .products import Products, ProductsProducts
from .protocol import (
    Protocol,
    ProtocolProtocol,
    ProtocolProtocolCompounds,
    ProtocolProtocolEvidenceRefs,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityArticle,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityEpisode,
    ProtocolProtocolEvidenceRefsEvidenceRefEntityExternal,
    ProtocolProtocolProducts,
    ProtocolProtocolSafety,
    ProtocolProtocolStepsStructured,
    ProtocolProtocolStepsStructuredItems,
    ProtocolProtocolStepsStructuredItemsItemEntityCompound,
    ProtocolProtocolStepsStructuredItemsItemEntityProduct,
)
from .protocols import Protocols, ProtocolsProtocols
from .register import Register, RegisterRegister, RegisterRegisterUser
from .save_entity import SaveEntity, SaveEntitySaveEntity
from .saved_entities import (
    SavedEntities,
    SavedEntitiesSavedEntities,
    SavedEntitiesSavedEntitiesEdges,
    SavedEntitiesSavedEntitiesEdgesNode,
    SavedEntitiesSavedEntitiesEdgesNodeTargetArticle,
    SavedEntitiesSavedEntitiesEdgesNodeTargetBusiness,
    SavedEntitiesSavedEntitiesEdgesNodeTargetCaseStudy,
    SavedEntitiesSavedEntitiesEdgesNodeTargetCompound,
    SavedEntitiesSavedEntitiesEdgesNodeTargetEpisode,
    SavedEntitiesSavedEntitiesEdgesNodeTargetPerson,
    SavedEntitiesSavedEntitiesEdgesNodeTargetProduct,
    SavedEntitiesSavedEntitiesEdgesNodeTargetProtocol,
    SavedEntitiesSavedEntitiesPageInfo,
)
from .unsave_entity import UnsaveEntity
from .update_business import UpdateBusiness, UpdateBusinessUpdateBusiness
from .update_business_relations import (
    UpdateBusinessRelations,
    UpdateBusinessRelationsUpdateBusinessRelations,
)
from .update_case_study import UpdateCaseStudy, UpdateCaseStudyUpdateCaseStudy
from .update_compound import UpdateCompound, UpdateCompoundUpdateCompound
from .update_compound_relations import (
    UpdateCompoundRelations,
    UpdateCompoundRelationsUpdateCompoundRelations,
)
from .update_episode import UpdateEpisode, UpdateEpisodeUpdateEpisode
from .update_episode_relations import (
    UpdateEpisodeRelations,
    UpdateEpisodeRelationsUpdateEpisodeRelations,
)
from .update_person import UpdatePerson, UpdatePersonUpdatePerson
from .update_product import UpdateProduct, UpdateProductUpdateProduct
from .update_product_relations import (
    UpdateProductRelations,
    UpdateProductRelationsUpdateProductRelations,
)
from .update_protocol import (
    UpdateProtocol,
    UpdateProtocolUpdateProtocol,
    UpdateProtocolUpdateProtocolCompounds,
    UpdateProtocolUpdateProtocolEvidenceRefs,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityArticle,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityEpisode,
    UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityExternal,
    UpdateProtocolUpdateProtocolProducts,
    UpdateProtocolUpdateProtocolSafety,
    UpdateProtocolUpdateProtocolStepsStructured,
    UpdateProtocolUpdateProtocolStepsStructuredItems,
    UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityCompound,
    UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityProduct,
)
from .update_protocol_relations import (
    UpdateProtocolRelations,
    UpdateProtocolRelationsUpdateProtocolRelations,
    UpdateProtocolRelationsUpdateProtocolRelationsCompounds,
    UpdateProtocolRelationsUpdateProtocolRelationsProducts,
)
from .update_user_protocol import (
    UpdateUserProtocol,
    UpdateUserProtocolUpdateUserProtocol,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefs,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityArticle,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityEpisode,
    UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityExternal,
    UpdateUserProtocolUpdateUserProtocolSafety,
    UpdateUserProtocolUpdateUserProtocolStepsStructured,
    UpdateUserProtocolUpdateUserProtocolStepsStructuredItems,
    UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityCompound,
    UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityProduct,
)
from .upsert_user import UpsertUser, UpsertUserUpsertUser
from .upsert_user_profile import (
    UpsertUserProfile,
    UpsertUserProfileUpsertUserProfile,
    UpsertUserProfileUpsertUserProfileEntityPreferences,
    UpsertUserProfileUpsertUserProfileGoals,
)
from .vector_search_businesses import (
    VectorSearchBusinesses,
    VectorSearchBusinessesVectorSearchBusinesses,
)
from .vector_search_people import (
    VectorSearchPeople,
    VectorSearchPeopleVectorSearchPeople,
)
from .vector_search_products import (
    VectorSearchProducts,
    VectorSearchProductsVectorSearchProducts,
)

__all__ = [
    "AllUsers",
    "AllUsersAllUsers",
    "ArticleSourceType",
    "AsyncBaseClient",
    "BaseModel",
    "Business",
    "BusinessBusiness",
    "BusinessBusinessExecutives",
    "BusinessBusinessExecutivesPerson",
    "BusinessBusinessMediaLinks",
    "BusinessBusinessOwners",
    "BusinessBusinessProducts",
    "BusinessBusinessSponsoredEpisodes",
    "BusinessCreateRelationsInput",
    "BusinessEpisodeNestedInput",
    "BusinessExecutiveNestedInput",
    "BusinessExecutiveRelationInput",
    "BusinessOwnerNestedInput",
    "BusinessProductNestedInput",
    "BusinessUpdateRelationFieldsInput",
    "BusinessUpdateWithIdsInput",
    "Businesses",
    "BusinessesBusinesses",
    "CaseStudies",
    "CaseStudiesCaseStudies",
    "CaseStudy",
    "CaseStudyCaseStudy",
    "CaseStudyCaseStudyCompounds",
    "CaseStudyCaseStudyEpisodes",
    "CaseStudyCaseStudyMediaLinks",
    "CaseStudyCaseStudyProducts",
    "CaseStudyCaseStudyProtocols",
    "CaseStudyCreateWithOptionalIdsInput",
    "CaseStudySourceType",
    "CaseStudyUpdateWithOptionalIdsInput",
    "Client",
    "Compound",
    "CompoundCompound",
    "CompoundCompoundCaseStudies",
    "CompoundCompoundMediaLinks",
    "CompoundCompoundProducts",
    "CompoundCreateWithIdsInput",
    "CompoundProductNestedInput",
    "CompoundUpdateRelationFieldsInput",
    "CompoundUpdateWithIdsInput",
    "Compounds",
    "CompoundsCompounds",
    "CreateBusinessWithRelations",
    "CreateBusinessWithRelationsCreateBusinessWithRelations",
    "CreateCaseStudy",
    "CreateCaseStudyCreateCaseStudy",
    "CreateCompound",
    "CreateCompoundCreateCompound",
    "CreateEpisode",
    "CreateEpisodeCreateEpisode",
    "CreatePerson",
    "CreatePersonCreatePerson",
    "CreateProduct",
    "CreateProductCreateProduct",
    "CreateProtocol",
    "CreateProtocolCreateProtocol",
    "CreateUserProtocol",
    "CreateUserProtocolCreateUserProtocol",
    "CreateUserProtocolCreateUserProtocolEvidenceRefs",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityArticle",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "CreateUserProtocolCreateUserProtocolEvidenceRefsEvidenceRefEntityExternal",
    "CreateUserProtocolCreateUserProtocolSafety",
    "CreateUserProtocolCreateUserProtocolStepsStructured",
    "CreateUserProtocolCreateUserProtocolStepsStructuredItems",
    "CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityCompound",
    "CreateUserProtocolCreateUserProtocolStepsStructuredItemsItemEntityProduct",
    "CreateUserProtocolInput",
    "CursorPageInput",
    "DeleteAllEpisodes",
    "DeleteAllEpisodesDeleteAllEpisodes",
    "DeleteBusiness",
    "DeleteBusinessDeleteBusiness",
    "DeleteCompound",
    "DeleteCompoundDeleteCompound",
    "DeleteEpisode",
    "DeleteEpisodeDeleteEpisode",
    "DeletePerson",
    "DeletePersonDeletePerson",
    "DeleteProduct",
    "DeleteProductDeleteProduct",
    "DeleteProtocol",
    "DeleteProtocolDeleteProtocol",
    "DeleteUser",
    "DeleteUserDeleteUser",
    "DeleteUserProfile",
    "DeleteUserProfileDeleteUserProfile",
    "DeleteUserProtocol",
    "DietStyle",
    "EmbedBusinessDescription",
    "EmbedBusinessDescriptionEmbedBusinessDescription",
    "EmbedPersonBio",
    "EmbedPersonBioEmbedPersonBio",
    "EmbedProductDescription",
    "EmbedProductDescriptionEmbedProductDescription",
    "EntityPreferencesInput",
    "Episode",
    "EpisodeCreateWithIdsInput",
    "EpisodeEpisode",
    "EpisodeEpisodeGuests",
    "EpisodeEpisodeMediaLinks",
    "EpisodeEpisodeProtocols",
    "EpisodeEpisodeSponsorBusinesses",
    "EpisodeEpisodeSponsorLinkObjects",
    "EpisodeEpisodeWebPageTimelines",
    "EpisodeGuestNestedInput",
    "EpisodeSponsorBusinessNestedInput",
    "EpisodeUpdateRelationFieldsInput",
    "EpisodeUpdateWithIdsInput",
    "Episodes",
    "EpisodesEpisodes",
    "EvidenceRefInput",
    "EvidenceRefType",
    "ExperienceLevel",
    "GoalType",
    "GraphQLClientError",
    "GraphQLClientGraphQLError",
    "GraphQLClientGraphQLMultiError",
    "GraphQLClientHttpError",
    "GraphQLClientInvalidResponseError",
    "Login",
    "LoginLogin",
    "LoginLoginUser",
    "Me",
    "MeMe",
    "MeMeProfile",
    "MeMeProfileEntityPreferences",
    "MeMeProfileGoals",
    "MediaLinkInput",
    "MyProfile",
    "MyProfileMyProfile",
    "MyProfileMyProfileEntityPreferences",
    "MyProfileMyProfileGoals",
    "MyUserProtocols",
    "MyUserProtocolsMyUserProtocols",
    "MyUserProtocolsMyUserProtocolsEdges",
    "MyUserProtocolsMyUserProtocolsEdgesNode",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefs",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityArticle",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityCaseStudy",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityEpisode",
    "MyUserProtocolsMyUserProtocolsEdgesNodeEvidenceRefsEvidenceRefEntityExternal",
    "MyUserProtocolsMyUserProtocolsEdgesNodeSafety",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructured",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItems",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityCompound",
    "MyUserProtocolsMyUserProtocolsEdgesNodeStepsStructuredItemsItemEntityProduct",
    "MyUserProtocolsMyUserProtocolsPageInfo",
    "People",
    "PeoplePeople",
    "Person",
    "PersonCreateInput",
    "PersonPerson",
    "PersonPersonBusinesses",
    "PersonPersonEpisodes",
    "PersonPersonMediaLinks",
    "PersonUpdateInput",
    "PreferredFormat",
    "Product",
    "ProductCompoundNestedInput",
    "ProductCreateWithIdsInput",
    "ProductProduct",
    "ProductProductBusiness",
    "ProductProductCompounds",
    "ProductProductMediaLinks",
    "ProductProductSponsorEpisodes",
    "ProductProtocolNestedInput",
    "ProductUpdateRelationFieldsInput",
    "ProductUpdateWithIdsInput",
    "Products",
    "ProductsProducts",
    "Protocol",
    "ProtocolCategory",
    "ProtocolCompoundNestedInput",
    "ProtocolCreateWithIdsInput",
    "ProtocolProductNestedInput",
    "ProtocolProtocol",
    "ProtocolProtocolCompounds",
    "ProtocolProtocolEvidenceRefs",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityArticle",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "ProtocolProtocolEvidenceRefsEvidenceRefEntityExternal",
    "ProtocolProtocolProducts",
    "ProtocolProtocolSafety",
    "ProtocolProtocolStepsStructured",
    "ProtocolProtocolStepsStructuredItems",
    "ProtocolProtocolStepsStructuredItemsItemEntityCompound",
    "ProtocolProtocolStepsStructuredItemsItemEntityProduct",
    "ProtocolStepGroupInput",
    "ProtocolStepItemInput",
    "ProtocolStepItemType",
    "ProtocolTimeOfDay",
    "ProtocolUpdateRelationFieldsInput",
    "ProtocolUpdateWithIdsInput",
    "Protocols",
    "ProtocolsProtocols",
    "Register",
    "RegisterRegister",
    "RegisterRegisterUser",
    "SafetyBucketInput",
    "SaveEntity",
    "SaveEntityInput",
    "SaveEntitySaveEntity",
    "SaveSource",
    "SavedEntities",
    "SavedEntitiesFilterInput",
    "SavedEntitiesSavedEntities",
    "SavedEntitiesSavedEntitiesEdges",
    "SavedEntitiesSavedEntitiesEdgesNode",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetArticle",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetBusiness",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetCaseStudy",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetCompound",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetEpisode",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetPerson",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetProduct",
    "SavedEntitiesSavedEntitiesEdgesNodeTargetProtocol",
    "SavedEntitiesSavedEntitiesPageInfo",
    "SavedEntityType",
    "SponsorLinkObjectInput",
    "TimeBudget",
    "UnsaveEntity",
    "UnsaveEntityInput",
    "UpdateBusiness",
    "UpdateBusinessRelations",
    "UpdateBusinessRelationsUpdateBusinessRelations",
    "UpdateBusinessUpdateBusiness",
    "UpdateCaseStudy",
    "UpdateCaseStudyUpdateCaseStudy",
    "UpdateCompound",
    "UpdateCompoundRelations",
    "UpdateCompoundRelationsUpdateCompoundRelations",
    "UpdateCompoundUpdateCompound",
    "UpdateEpisode",
    "UpdateEpisodeRelations",
    "UpdateEpisodeRelationsUpdateEpisodeRelations",
    "UpdateEpisodeUpdateEpisode",
    "UpdatePerson",
    "UpdatePersonUpdatePerson",
    "UpdateProduct",
    "UpdateProductRelations",
    "UpdateProductRelationsUpdateProductRelations",
    "UpdateProductUpdateProduct",
    "UpdateProtocol",
    "UpdateProtocolRelations",
    "UpdateProtocolRelationsUpdateProtocolRelations",
    "UpdateProtocolRelationsUpdateProtocolRelationsCompounds",
    "UpdateProtocolRelationsUpdateProtocolRelationsProducts",
    "UpdateProtocolUpdateProtocol",
    "UpdateProtocolUpdateProtocolCompounds",
    "UpdateProtocolUpdateProtocolEvidenceRefs",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityArticle",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "UpdateProtocolUpdateProtocolEvidenceRefsEvidenceRefEntityExternal",
    "UpdateProtocolUpdateProtocolProducts",
    "UpdateProtocolUpdateProtocolSafety",
    "UpdateProtocolUpdateProtocolStepsStructured",
    "UpdateProtocolUpdateProtocolStepsStructuredItems",
    "UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityCompound",
    "UpdateProtocolUpdateProtocolStepsStructuredItemsItemEntityProduct",
    "UpdateUserProtocol",
    "UpdateUserProtocolInput",
    "UpdateUserProtocolUpdateUserProtocol",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefs",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityArticle",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityCaseStudy",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityEpisode",
    "UpdateUserProtocolUpdateUserProtocolEvidenceRefsEvidenceRefEntityExternal",
    "UpdateUserProtocolUpdateUserProtocolSafety",
    "UpdateUserProtocolUpdateUserProtocolStepsStructured",
    "UpdateUserProtocolUpdateUserProtocolStepsStructuredItems",
    "UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityCompound",
    "UpdateUserProtocolUpdateUserProtocolStepsStructuredItemsItemEntityProduct",
    "Upload",
    "UpsertUser",
    "UpsertUserProfile",
    "UpsertUserProfileUpsertUserProfile",
    "UpsertUserProfileUpsertUserProfileEntityPreferences",
    "UpsertUserProfileUpsertUserProfileGoals",
    "UpsertUserUpsertUser",
    "UserCreateInput",
    "UserGoalInput",
    "UserGoalType",
    "UserProfileUpsertInput",
    "UserProtocolStatus",
    "UserProtocolsFilterInput",
    "UserProvider",
    "UserRole",
    "UserUpsertInput",
    "VectorSearchArgs",
    "VectorSearchBusinesses",
    "VectorSearchBusinessesVectorSearchBusinesses",
    "VectorSearchPeople",
    "VectorSearchPeopleVectorSearchPeople",
    "VectorSearchProducts",
    "VectorSearchProductsVectorSearchProducts",
    "WebPageTimelineInput",
]



# Generated by ariadne-codegen
# Source: ../../src/graphql/operations

from typing import Optional

from .base_model import BaseModel


class People(BaseModel):
    people: list["PeoplePeople"]


class PeoplePeople(BaseModel):
    id: str
    name: str
    role: Optional[str]


People.model_rebuild()
